%%
%% This is file `t2aenc.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% cyoutenc.dtx  (with options: `T2A')
%% 
%% IMPORTANT NOTICE:
%% 
%% For the copyright see the source file.
%% 
%% Any modified versions of this file must be renamed
%% with new filenames distinct from t2aenc.def.
%% 
%% For distribution of the original source see the terms
%% for copying and modification in the file cyoutenc.dtx.
%% 
%% This generated file may be distributed as long as the
%% original source files, as listed above, are part of the
%% same distribution. (The sources need not necessarily be
%% in the same archive or directory.)
\ProvidesFile{t2aenc.def}
  [1998/11/12 v1.0 Cyrillic encoding definition file]
\@ifl@aded{ltx}{textmath}\relax{\input{textmath.ltx}}
\def\@tmpd{T2A}
\def\@tmpa#1#2{%
  \DeclareTextMathSymbol#1{\@tmpd}{\mathalpha}{\@tmpd letters}{#2}}
\def\@tmpb#1#2#3#4{%
  \ifx#1\undefined
    \expandafter\def\expandafter\@uclclist\expandafter{\@uclclist#3#1}%
  \fi \@tmpa#1{#2}\@tmpa#3{#4}}
\def\@tmpc#1#2{\DeclareTextAccent{#1}{\@tmpd}{#2}}
\DeclareFontEncoding{\@tmpd}{}{}
\DeclareFontSubstitution{\@tmpd}{cmr}{m}{n}
\DeclareSymbolFont{\@tmpd letters}{\@tmpd}
  \rmdefault\mddefault\updefault
\SetSymbolFont{\@tmpd letters}{bold}{\@tmpd}
  \rmdefault\bfdefault\updefault
\@tmpc{\`}{0}
\@tmpc{\'}{1}
\@tmpc{\^}{2}
\@tmpc{\~}{3}
\@tmpc{\"}{4}
\@tmpc{\H}{5}
\@tmpc{\r}{6}
\@tmpc{\v}{7}
\@tmpc{\u}{8}
\@tmpc{\=}{9}
\@tmpc{\.}{10}
\@tmpc{\F}{18}
\@tmpc{\C}{19}
\@tmpc{\U}{20}
\DeclareTextCommand{\b}{\@tmpd}[1]
   {{\o@lign{\relax#1\crcr\hidewidth\sh@ft{29}%
     \vbox to.2ex{\hbox{\char9}\vss}\hidewidth}}}
\DeclareTextCommand{\c}{\@tmpd}[1]
   {\leavevmode\setbox\z@\hbox{#1}\ifdim\ht\z@=1ex\accent11 #1%
     \else{\ooalign{\hidewidth\char11\hidewidth
        \crcr\unhbox\z@}}\fi}
\DeclareTextCommand{\d}{\@tmpd}[1]
   {{\o@lign{\relax#1\crcr\hidewidth\sh@ft{10}.\hidewidth}}}
\DeclareTextCommand{\k}{\@tmpd}[1]
   {\oalign{\null#1\crcr\hidewidth\char12}}
\DeclareTextCommand{\textperthousand}{\@tmpd}
   {\%\char 24 }
\DeclareTextCommand{\textpertenthousand}{\@tmpd}
   {\%\char 24\char 24 }
\@tmpa{\endash}{21}
\@tmpa{\emdash}{22}
\@tmpa{\compwordmark}{23}
\@tmpa{\visiblespace}{32}
\@tmpa{\dollar}{36}
\@tmpa{\less}{60}
\@tmpa{\greater}{62}
\DeclareTextSymbol{\textbackslash}{\@tmpd}{92}
\@tmpa{\asciicircum}{94}
\@tmpa{\underscore}{95}
\@tmpa{\braceleft}{123}
\DeclareTextSymbol{\textbar}{\@tmpd}{124}
\@tmpa{\braceright}{125}
\@tmpa{\asciitilde}{126}
\@tmpa{\numero}{157}
\@tmpa{\currency}{158}
\DeclareTextSymbol{\textsection}{\@tmpd}{159}
\@tmpa{\quotedbl}{34}
\@tmpa{\quoteleft}{96}
\@tmpa{\quoteright}{39}
\@tmpa{\quotedblleft}{16}
\@tmpa{\quotedblright}{17}
\@tmpa{\quotedblbase}{189}
\@tmpa{\CYRpalochka}{13}
\@tmpa{\cyrlangle}{14}
\@tmpa{\cyrrangle}{15}
\@tmpa{\guillemotleft}{190}
\@tmpa{\guillemotright}{191}
\@tmpa{\i}{25}
\@tmpa{\j}{26}
\DeclareTextComposite{\.}{\@tmpd}{i}{`\i}
\@tmpb{\CYRA}{192}{\cyra}{224}
\@tmpb{\CYRB}{193}{\cyrb}{225}
\@tmpb{\CYRV}{194}{\cyrv}{226}
\@tmpb{\CYRG}{195}{\cyrg}{227}
\@tmpb{\CYRD}{196}{\cyrd}{228}
\@tmpb{\CYRE}{197}{\cyre}{229}
\@tmpb{\CYRZH}{198}{\cyrzh}{230}
\@tmpb{\CYRZ}{199}{\cyrz}{231}
\@tmpb{\CYRI}{200}{\cyri}{232}
\@tmpb{\CYRISHRT}{201}{\cyrishrt}{233}
\@tmpb{\CYRK}{202}{\cyrk}{234}
\@tmpb{\CYRL}{203}{\cyrl}{235}
\@tmpb{\CYRM}{204}{\cyrm}{236}
\@tmpb{\CYRN}{205}{\cyrn}{237}
\@tmpb{\CYRO}{206}{\cyro}{238}
\@tmpb{\CYRP}{207}{\cyrp}{239}
\@tmpb{\CYRR}{208}{\cyrr}{240}
\@tmpb{\CYRS}{209}{\cyrs}{241}
\@tmpb{\CYRT}{210}{\cyrt}{242}
\@tmpb{\CYRU}{211}{\cyru}{243}
\@tmpb{\CYRF}{212}{\cyrf}{244}
\@tmpb{\CYRH}{213}{\cyrh}{245}
\@tmpb{\CYRC}{214}{\cyrc}{246}
\@tmpb{\CYRCH}{215}{\cyrch}{247}
\@tmpb{\CYRSH}{216}{\cyrsh}{248}
\@tmpb{\CYRSHCH}{217}{\cyrshch}{249}
\@tmpb{\CYRHRDSN}{218}{\cyrhrdsn}{250}
\@tmpb{\CYRERY}{219}{\cyrery}{251}
\@tmpb{\CYRSFTSN}{220}{\cyrsftsn}{252}
\@tmpb{\CYREREV}{221}{\cyrerev}{253}
\@tmpb{\CYRYU}{222}{\cyryu}{254}
\@tmpb{\CYRYA}{223}{\cyrya}{255}
\@tmpb{\CYRGUP}{128}{\cyrgup}{160}
\@tmpb{\CYRGHCRS}{129}{\cyrghcrs}{161}
\@tmpb{\CYRDJE}{130}{\cyrdje}{162}
\@tmpb{\CYRTSHE}{131}{\cyrtshe}{163}
\@tmpb{\CYRSHHA}{132}{\cyrshha}{164}
\@tmpb{\CYRZHDSC}{133}{\cyrzhdsc}{165}
\@tmpb{\CYRZDSC}{134}{\cyrzdsc}{166}
\@tmpb{\CYRLJE}{135}{\cyrlje}{167}
\@tmpb{\CYRYI}{136}{\cyryi}{168}
\@tmpb{\CYRKDSC}{137}{\cyrkdsc}{169}
\@tmpb{\CYRKBEAK}{138}{\cyrkbeak}{170}
\@tmpb{\CYRKVCRS}{139}{\cyrkvcrs}{171}
\@tmpb{\CYRAE}{140}{\cyrae}{172}
\@tmpb{\CYRNDSC}{141}{\cyrndsc}{173}
\@tmpb{\CYRNG}{142}{\cyrng}{174}
\@tmpb{\CYRDZE}{143}{\cyrdze}{175}
\@tmpb{\CYROTLD}{144}{\cyrotld}{176}
\@tmpb{\CYRSDSC}{145}{\cyrsdsc}{177}
\@tmpb{\CYRUSHRT}{146}{\cyrushrt}{178}
\@tmpb{\CYRY}{147}{\cyry}{179}
\@tmpb{\CYRYHCRS}{148}{\cyryhcrs}{180}
\@tmpb{\CYRHDSC}{149}{\cyrhdsc}{181}
\@tmpb{\CYRDZHE}{150}{\cyrdzhe}{182}
\@tmpb{\CYRCHVCRS}{151}{\cyrchvcrs}{183}
\@tmpb{\CYRCHRDSC}{152}{\cyrchrdsc}{184}
\@tmpb{\CYRIE}{153}{\cyrie}{185}
\@tmpb{\CYRSCHWA}{154}{\cyrschwa}{186}
\@tmpb{\CYRNJE}{155}{\cyrnje}{187}
\@tmpb{\CYRYO}{156}{\cyryo}{188}
\@tmpb{\CYRII}{73}{\cyrii}{105}
\@tmpb{\CYRJE}{74}{\cyrje}{106}
\@tmpb{\CYRQ}{81}{\cyrq}{113}
\@tmpb{\CYRW}{87}{\cyrw}{119}
\let\@tmpa\undefined
\let\@tmpb\undefined
\let\@tmpc\undefined
\let\@tmpd\undefined
\endinput
%%
%% End of file `t2aenc.def'.
