%%
%% This is file `cp1252.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% inputenc.dtx  (with options: `cp1252')
%% 
%% This is a generated file.
%% 
%% Copyright 1993 1994 1995 1996 1997
%% The LaTeX3 Project and any individual authors listed elsewhere
%% in this file.
%% 
%% For further copyright information, and conditions for modification
%% and distribution, see the file legal.txt, and any other copyright
%% notices in this file.
%% 
%% This file is part of the LaTeX2e system.
%% ----------------------------------------
%%   This system is distributed in the hope that it will be useful,
%%   but WITHOUT ANY WARRANTY; without even the implied warranty of
%%   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
%% 
%%   For error reports concerning UNCHANGED versions of this file no
%%   more than one year old, see bugs.txt.
%% 
%%   Please do not request updates from us directly.  Primary
%%   distribution is through the CTAN archives.
%% 
%% 
%% IMPORTANT COPYRIGHT NOTICE:
%% 
%% You are NOT ALLOWED to distribute this file alone.
%% 
%% You are allowed to distribute this file under the condition that it
%% is distributed together with all the files listed in manifest.txt.
%% 
%% If you receive only some of these files from someone, complain!
%% 
%% 
%% Permission is granted to copy this file to another file with a
%% clearly different name and to customize the declarations in that
%% copy to serve the needs of your installation, provided that you
%% comply with the conditions in the file legal.txt.
%% 
%% However, NO PERMISSION is granted to generate or to distribute a
%% modified version of this file under its original name.
%% 
%% You are NOT ALLOWED to change this file.
%% 
%% 
%% MODIFICATION ADVICE:
%% 
%% If you want to customize this file, it is best to make a copy of
%% the source file(s) from which it was produced.  Use a different
%% name for your copy(ies) and modify the copy(ies); this will ensure
%% that your modifications do not get overwritten when you install a
%% new release of the standard system.  You should also ensure that
%% your modified source file does not generate any modified file with
%% the same name as a standard file.
%% 
%% You can then easily distribute your modifications by distributing
%% the modified and renamed copy of the source file, taking care to
%% observe the conditions in legal.txt; this will ensure that other
%% users can safely use your modifications.
%% 
%% You will also need to produce your own, suitably named, .ins file to
%% control the generation of files from your source file; this file
%% should contain your own preambles for the files it generates, not
%% those in the standard .ins files.
%% 
%% The names of the source files used are shown above.
%% 
%% 
%% 
%% \CharacterTable
%%  {Upper-case    \A\B\C\D\E\F\G\H\I\J\K\L\M\N\O\P\Q\R\S\T\U\V\W\X\Y\Z
%%   Lower-case    \a\b\c\d\e\f\g\h\i\j\k\l\m\n\o\p\q\r\s\t\u\v\w\x\y\z
%%   Digits        \0\1\2\3\4\5\6\7\8\9
%%   Exclamation   \!     Double quote  \"     Hash (number) \#
%%   Dollar        \$     Percent       \%     Ampersand     \&
%%   Acute accent  \'     Left paren    \(     Right paren   \)
%%   Asterisk      \*     Plus          \+     Comma         \,
%%   Minus         \-     Point         \.     Solidus       \/
%%   Colon         \:     Semicolon     \;     Less than     \<
%%   Equals        \=     Greater than  \>     Question mark \?
%%   Commercial at \@     Left bracket  \[     Backslash     \\
%%   Right bracket \]     Circumflex    \^     Underscore    \_
%%   Grave accent  \`     Left brace    \{     Vertical bar  \|
%%   Right brace   \}     Tilde         \~}
  \ProvidesFile{cp1252.def}
   [1998/03/05 v0.97 Input encoding file
                        (test version: still liable to change)]
\makeatletter
\ProvideTextCommandDefault{\textdegree}{\ensuremath{{^\circ}}}
\ProvideTextCommandDefault{\textonehalf}{\ensuremath{\frac12}}
\ProvideTextCommandDefault{\textonequarter}{\ensuremath{\frac14}}
\ProvideTextCommandDefault{\textthreequarters}{\ensuremath{\frac34}}
\ProvideTextCommandDefault{\textflorin}{\textit{f}}
\ProvideTextCommandDefault{\textcent}
   {\TextSymbolUnavailable\textcent}
\ProvideTextCommandDefault{\textyen}
   {\TextSymbolUnavailable\textyen}
\ProvideTextCommandDefault{\textcurrency}
   {\TextSymbolUnavailable\textcurrency}
\ProvideTextCommandDefault{\textbrokenbar}
   {\TextSymbolUnavailable\textbrokenbar}
\ProvideTextCommandDefault{\textperthousand}
   {\TextSymbolUnavailable\textperthousand}
\providecommand{\mathonesuperior}{{^1}}
\providecommand{\maththreesuperior}{{^3}}
\providecommand{\mathtwosuperior}{{^2}}
\DeclareInputText{130}{\quotesinglbase}
\DeclareInputText{131}{\textflorin}
\DeclareInputText{132}{\quotedblbase}
\DeclareInputText{133}{\dots}
\DeclareInputText{134}{\dag}
\DeclareInputText{135}{\ddag}
\DeclareInputText{136}{\^{}}
\DeclareInputText{137}{\textperthousand}
\DeclareInputText{138}{\v S}
\DeclareInputText{139}{\guilsinglleft}
\DeclareInputText{140}{\OE}
\DeclareInputText{145}{\textquoteleft}
\DeclareInputText{146}{\textquoteright}
\DeclareInputText{147}{\textquotedblleft}
\DeclareInputText{148}{\textquotedblright}
\DeclareInputText{149}{\textbullet}
\DeclareInputText{150}{\textendash}
\DeclareInputText{151}{\textemdash}
\DeclareInputText{152}{\~{}}
\DeclareInputText{153}{\texttrademark}
\DeclareInputText{154}{\v s}
\DeclareInputText{155}{\guilsinglright}
\DeclareInputText{156}{\oe}
\DeclareInputText{159}{\"Y}
\DeclareInputText{160}{\nobreakspace}
\DeclareInputText{176}{\textdegree}
\DeclareInputText{161}{\textexclamdown}
\DeclareInputMath{177}{\pm}
\DeclareInputText{162}{\textcent}
\DeclareInputMath{178}{\mathtwosuperior}
\DeclareInputText{163}{\pounds}
\DeclareInputMath{179}{\maththreesuperior}
\DeclareInputText{164}{\textcurrency}
\DeclareInputText{180}{\@tabacckludge'{}}
\DeclareInputText{165}{\textyen}
\DeclareInputMath{181}{\mu}
\DeclareInputText{166}{\textbrokenbar}
\DeclareInputText{182}{\P}
\DeclareInputText{167}{\S}
\DeclareInputText{183}{\textperiodcentered}
\DeclareInputText{168}{\"{}}
\DeclareInputText{184}{\c\ }
\DeclareInputText{169}{\copyright}
\DeclareInputMath{185}{\mathonesuperior}
\DeclareInputText{170}{\textordfeminine}
\DeclareInputText{186}{\textordmasculine}
\DeclareInputText{171}{\guillemotleft}
\DeclareInputText{187}{\guillemotright}
\DeclareInputMath{172}{\lnot}
\DeclareInputText{188}{\textonequarter}
\DeclareInputText{173}{\-}
\DeclareInputText{189}{\textonehalf}
\DeclareInputText{174}{\textregistered}
\DeclareInputText{190}{\textthreequarters}
\DeclareInputText{175}{\@tabacckludge={}}
\DeclareInputText{191}{\textquestiondown}
\DeclareInputText{192}{\@tabacckludge`A}
\DeclareInputText{208}{\DH}
\DeclareInputText{193}{\@tabacckludge'A}
\DeclareInputText{209}{\~N}
\DeclareInputText{194}{\^A}
\DeclareInputText{210}{\@tabacckludge`O}
\DeclareInputText{195}{\~A}
\DeclareInputText{211}{\@tabacckludge'O}
\DeclareInputText{196}{\"A}
\DeclareInputText{212}{\^O}
\DeclareInputText{197}{\r A}
\DeclareInputText{213}{\~O}
\DeclareInputText{198}{\AE}
\DeclareInputText{214}{\"O}
\DeclareInputText{199}{\c C}
\DeclareInputMath{215}{\times}
\DeclareInputText{200}{\@tabacckludge`E}
\DeclareInputText{216}{\O}
\DeclareInputText{201}{\@tabacckludge'E}
\DeclareInputText{217}{\@tabacckludge`U}
\DeclareInputText{202}{\^E}
\DeclareInputText{218}{\@tabacckludge'U}
\DeclareInputText{203}{\"E}
\DeclareInputText{219}{\^U}
\DeclareInputText{204}{\@tabacckludge`I}
\DeclareInputText{220}{\"U}
\DeclareInputText{205}{\@tabacckludge'I}
\DeclareInputText{221}{\@tabacckludge'Y}
\DeclareInputText{206}{\^I}
\DeclareInputText{222}{\TH}
\DeclareInputText{207}{\"I}
\DeclareInputText{223}{\ss}
\DeclareInputText{224}{\@tabacckludge`a}
\DeclareInputText{240}{\dh}
\DeclareInputText{225}{\@tabacckludge'a}
\DeclareInputText{241}{\~n}
\DeclareInputText{226}{\^a}
\DeclareInputText{242}{\@tabacckludge`o}
\DeclareInputText{227}{\~a}
\DeclareInputText{243}{\@tabacckludge'o}
\DeclareInputText{228}{\"a}
\DeclareInputText{244}{\^o}
\DeclareInputText{229}{\r a}
\DeclareInputText{245}{\~o}
\DeclareInputText{230}{\ae}
\DeclareInputText{246}{\"o}
\DeclareInputText{231}{\c c}
\DeclareInputMath{247}{\div}
\DeclareInputText{232}{\@tabacckludge`e}
\DeclareInputText{248}{\o}
\DeclareInputText{233}{\@tabacckludge'e}
\DeclareInputText{249}{\@tabacckludge`u}
\DeclareInputText{234}{\^e}
\DeclareInputText{250}{\@tabacckludge'u}
\DeclareInputText{235}{\"e}
\DeclareInputText{251}{\^u}
\DeclareInputText{236}{\@tabacckludge`\i}
\DeclareInputText{252}{\"u}
\DeclareInputText{237}{\@tabacckludge'\i}
\DeclareInputText{253}{\@tabacckludge'y}
\DeclareInputText{238}{\^\i}
\DeclareInputText{254}{\th}
\DeclareInputText{239}{\"\i}
\DeclareInputText{255}{\"y}
\makeatother
\endinput
%%
%% End of file `cp1252.def'.
