%%
%% This is file `pdfmark.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% hyperref.dtx  (with options: `pdfmark,pdfmarkbase,pdfform,outlines')
%% 
%% File: hyperref.dtx Copyright (C) 1995, 1996, 1997, 1998 Sebastian Rahtz
\def\hyper@anchor#1{%
   {\pdfmark[\anchor@spot]{pdfmark=/DEST,linktype=anchor,View=/\@pdfview \@pdfviewparams,DestAnchor=#1}}%
}
\@ifundefined{hyper@anchorstart}{}{\endinput}
\def\hyper@anchorstart#1{%
  \PSHyperAnchorStart
  \global\edef\hyper@currentanchor{#1}%
  \hy@activeanchortrue
}
\def\hyper@anchorend{%
   \PSHyperAnchorEnd
   \pdfmark{pdfmark=/DEST,linktype=anchor,View=/\@pdfview  \@pdfviewparams,
       DestAnchor=\hyper@currentanchor,
       Rect=\pdf@bbox}%
  \hy@activeanchorfalse
}
\def\hyper@linkstart#1#2{%
   \ifhy@breaklinks\else
    \leavevmode\hbox\bgroup
   \fi
   \hy@colorlink{\csname @#1color\endcsname}%
   \PSHyperLinkStart
   \global\edef\hyper@currentanchor{#2}%
   \gdef\hyper@currentlinktype{#1}%
}
\def\hyper@linkend{%
    \PSHyperLinkEnd
    \edef\@foo{\csname @\hyper@currentlinktype bordercolor\endcsname}%
       \pdfmark{pdfmark=/ANN,linktype=link,Subtype=/Link,
           Dest=\hyper@currentanchor,
           AcroHighlight=\@pdfhighlight,
           Border=\@pdfborder,Color=\@foo,Rect=\pdf@bbox}%
   \hy@endcolorlink
   \ifhy@breaklinks\else\egroup\fi
}
\def\hyper@pagetransition{%
 \ifx\@pdfpagetransition\@empty
 \else
   \pdfmark{pdfmark=/PUT,Raw={{ThisPage}
       << /Trans << /S /\@pdfpagetransition\space >> >>}}%
 \fi
}
\def\hyper@image#1#2{%
  \hyper@linkurl{#2}{#1}}
\def\hyper@link#1#2#3{%
    \edef\@foo{\csname @#1bordercolor\endcsname}%
    \bgroup
 \pdfmark[#3]{Color=\@foo,linktype=#1,AcroHighlight=\@pdfhighlight,Border=\@pdfborder,pdfmark=/ANN,Subtype=/Link,Dest=#2}%
    \egroup
}
\newtoks\pdf@docset
\def\@pdfproducer{dvips + Distiller}
\def\PDF@FinishDoc{%
 \pdfmark{pdfmark=/DOCINFO,
  Title=\@pdftitle,
  Subject=\@pdfsubject,
  Creator= \@pdfcreator,
  Author=\@pdfauthor,
  Producer= \@pdfproducer,
  Keywords=\@pdfkeywords
  }%
}
\def\PDF@SetupDoc{%
 \ifx\@baseurl\@empty\def\@dobaseurl{}\else
     \def\@dobaseurl{}%
 \fi
 \pdfmark{pdfmark=/DOCVIEW,
   Page=\@pdfstartpage,
   View=\@pdfstartview,
   URI={<< /Base (\@baseurl) >>},
   PageMode=\@pdfpagemode
   }
 \ifx\@pdfpagescrop\@empty\else
   \pdfmark{pdfmark=/PAGES,CropBox=\@pdfpagescrop}%
 \fi
 \pdfmark{pdfmark=/PUT,Raw={
 \string{Catalog\string} <<
   /ViewerPreferences <<
  \ifhy@toolbar\else /HideToolbar true \fi
  \ifhy@menubar\else /HideMenubar true \fi
  \ifhy@windowui\else /HideWindowUI true \fi
  \ifhy@fitwindow /FitWindow true \fi
  \ifhy@centerwindow /CenterWindow true \fi
   >>
  \ifx\pdf@pagelayout\@empty\else/PageLayout /\pdf@pagelayout\space\fi
  >>}}%
}
\def\pdfmark{\@ifnextchar[{\pdfmark@}{\pdfmark@[]}}
\def\pdfmark@[#1]#2{%
    \edef\@processme{\noexpand\pdf@toks={ \the\pdf@defaulttoks}}%
    \@processme
    \let\pdf@type\relax
    \setkeys{PDF}{#2}%
    \ifx\pdf@type\relax
       \hyper@warn{no pdfmark type specified in #2!!}%
       \ifx\\#1\\\relax\else\pdf@rect{#1}\fi
    \else
       \ifx\\#1\\\relax
  \literalps@out{[\the\pdf@toks\space \pdf@type\space pdfmark}%
       \else
         \hy@colorlink{\@ifundefined{@\pdf@linktype color}%
                      {\@linkcolor}%
                      {\csname @\pdf@linktype color\endcsname}}%
         \pdf@rect{#1}%
  \literalps@out{[\the\pdf@toks\space \pdf@type\space pdfmark}%
         \hy@endcolorlink
       \fi
    \fi
}
\newsavebox{\pdf@box}
\def\pdf@rect#1{%
   \leavevmode
   \sbox\pdf@box{#1}%
   \dimen@\ht\pdf@box
   \leavevmode\lower\dp\pdf@box\hbox{\PSHyperRectStart}%
   \ifhy@breaklinks\unhbox\else\box\fi\pdf@box
   \raise\dimen@\hbox{\PSHyperRectEnd}%
   \pdf@addtoks{[\pdf@bbox]}{Rect}%
}
\newtoks\pdf@toks
\newtoks\pdf@defaulttoks
\pdf@defaulttoks={ }%
\def\pdf@addtoks#1#2{%
   \edef\@processme{\pdf@toks{\the\pdf@toks\space /#2 #1}}%
   \@processme
}
\def\pdf@addtoksx#1{%
   \edef\@processme{\pdf@toks{\the\pdf@toks\space #1}}%
   \@processme
}
\def\PDFdefaults#1{%
 \pdf@defaulttoks={#1}%
}
\define@key{PDF}{pdfmark}{\def\pdf@type{#1}}
\define@key{PDF}{linktype}{\def\pdf@linktype{#1}}
\def\pdf@linktype{link}
\define@key{PDF}{Raw}{\pdf@addtoksx{#1}}
\define@key{PDF}{Action}{\pdf@addtoks{#1}{Action}}
\define@key{PDF}{Border}{\pdf@addtoks{[#1]}{Border}}
\define@key{PDF}{Color}{\pdf@addtoks{[#1]}{Color}}
\define@key{PDF}{Contents}{\pdf@addtoks{(#1)}{Contents}}
\define@key{PDF}{Count}{\pdf@addtoks{#1}{Count}}
\define@key{PDF}{CropBox}{\pdf@addtoks{[#1]}{CropBox}}
\define@key{PDF}{DOSFile}{\pdf@addtoks{(#1)}{DOSFile}}
\define@key{PDF}{DataSource}{\pdf@addtoks{(#1)}{DataSource}}
\define@key{PDF}{Dest}{\ifx\\#1\\\else\pdf@addtoks{/#1}{Dest}\fi}
\define@key{PDF}{DestAnchor}{\ifx\\#1\\\else
      \pdf@addtoks{/#1 }{Dest}\fi}
\define@key{PDF}{Dir}{\pdf@addtoks{(#1)}{Dir}}
\define@key{PDF}{File}{\pdf@addtoks{(#1)}{File}}
\define@key{PDF}{Flags}{\pdf@addtoks{#1}{Flags}}
\define@key{PDF}{AcroHighlight}{\pdf@addtoks{#1}{H}}
\define@key{PDF}{ID}{\pdf@addtoks{[#1]}{ID}}
\define@key{PDF}{MacFile}{\pdf@addtoks{(#1)}{MacFile}}
\define@key{PDF}{ModDate}{\pdf@addtoks{(#1)}{ModDate}}
\define@key{PDF}{Op}{\pdf@addtoks{(#1)}{Op}}
\define@key{PDF}{Open}{\pdf@addtoks{#1}{Open}}
\define@key{PDF}{Page}{\pdf@addtoks{#1}{Page}}
\define@key{PDF}{PageMode}{\pdf@addtoks{#1}{PageMode}}
\define@key{PDF}{Params}{\pdf@addtoks{(#1)}{Params}}
\define@key{PDF}{Rect}{\pdf@addtoks{[#1]}{Rect}}
\define@key{PDF}{SrcPg}{\pdf@addtoks{#1}{SrcPg}}
\define@key{PDF}{Subtype}{\pdf@addtoks{#1}{Subtype}}
\define@key{PDF}{Title}{\pdf@addtoks{(#1)}{Title}}
\define@key{PDF}{Unix}{\pdf@addtoks{(#1)}{Unix}}
\define@key{PDF}{UnixFile}{\pdf@addtoks{(#1)}{UnixFile}}
\define@key{PDF}{View}{\pdf@addtoks{[#1]}{View}}
\define@key{PDF}{WinFile}{\pdf@addtoks{(#1)}{WinFile}}
\define@key{PDF}{Author}{\pdf@addtoks{(#1)}{Author}}
\define@key{PDF}{CreationDate}{\pdf@addtoks{(#1)}{CreationDate}}
\define@key{PDF}{Creator}{\pdf@addtoks{(#1)}{Creator}}
\define@key{PDF}{Producer}{\pdf@addtoks{(#1)}{Producer}}
\define@key{PDF}{Subject}{\pdf@addtoks{(#1)}{Subject}}
\define@key{PDF}{Keywords}{\pdf@addtoks{(#1)}{Keywords}}
\define@key{PDF}{ModDate}{\pdf@addtoks{(#1)}{ModDate}}
\define@key{PDF}{Base}{\pdf@addtoks{(#1)}{Base}}
\define@key{PDF}{URI}{\pdf@addtoks{#1}{URI}}
\def\Acrobatmenu#1#2{%
 \pdfmark[#2]{linktype=menu,pdfmark=/ANN,AcroHighlight=\@pdfhighlight,
    Border=\@pdfborder,Action=<< /Subtype /Named /N /#1 >>,Subtype=/Link}}
\def\PDFNextPage{\@ifnextchar[{\PDFNextPage@}{\PDFNextPage@[]}}
\def\PDFNextPage@[#1]#2{%
 \pdfmark[#2]{#1,Border=\@pdfborder,Color=.2 .1 .5,
  pdfmark=/ANN,Subtype=/Link,Page=/Next}}
\def\PDFPreviousPage{\@ifnextchar[{\PDFPreviousPage@}{\PDFPreviousPage@[]}}
\def\PDFPreviousPage@[#1]#2{%
 \pdfmark[#2]{#1,Border=\@pdfborder,Color=.4 .4 .1,
  pdfmark=/ANN,Subtype=/Link,Page=/Prev}}
\def\PDFOpen#1{%
  \pdfmark{#1,pdfmark=/DOCVIEW}%
}
\def\PDFPage{\@ifnextchar[{\PDFPage@}{\PDFPage@[]}}
\def\PDFPage@[#1]#2#3{%
 \let\pageref\simple@pageref
 \pdfmark[#3]{#1,Page=#2,AcroHighlight=\@pdfhighlight,Border=\@pdfborder,
   Color=\@pagebordercolor,pdfmark=/ANN,Subtype=/Link}}
\def\simple@pageref#1{%
  \expandafter\ifx\csname r@#1\endcsname\relax
   0%
  \else
    \expandafter\expandafter\expandafter
          \@secondoffive\csname r@#1\endcsname
  \fi}
\def\hyper@linkurl#1#2{%
 \bgroup\hyper@chars
 \pdfmark[#1]{pdfmark=/ANN,linktype=url,AcroHighlight=\@pdfhighlight,Border=\@pdfborder,Color=\@urlbordercolor,
 Action={<< /Subtype /URI /URI (#2) >>},Subtype=/Link}%
 \egroup
}
\def\hyper@linkfile#1#2#3{%
 \bgroup
\pdfmark[#1]{pdfmark=/ANN,Subtype=/Link,
  AcroHighlight=\@pdfhighlight,Border=\@pdfborder,
  linktype=file,Color=\@filebordercolor,
  Action=<<
    /S /GoToR
\ifhy@newwindow
    /NewWindow true
\fi
    /F (#2)
    /D \ifx\\#3\\[0 \@pdfstartview]\else(#3)\fi
         >>}%
 \egroup
}
\long\def\@Form[#1]{%
\AtBeginDvi{\special{!
[ /_objdef {pdfDocEncoding}
  /type /dict
/OBJ pdfmark
[ {pdfDocEncoding}
 << /Type /Encoding
/Differences [ 24 /breve /caron /circumflex /dotaccent
/hungarumlaut /ogonek /ring /tilde 39 /quotesingle 96 /grave 128
/bullet /dagger /daggerdbl /ellipsis /emdash /endash /florin /fraction
/guilsinglleft /guilsinglright /minus /perthousand /quotedblbase
/quotedblleft /quotedblright /quoteleft /quoteright /quotesinglbase
/trademark /fi /fl /Lslash /OE /Scaron /Ydieresis /Zcaron /dotlessi
/lslash /oe /scaron /zcaron 164 /currency 166 /brokenbar 168 /dieresis
/copyright /ordfeminine 172 /logicalnot /.notdef /registered /macron
/degree /plusminus /twosuperior /threesuperior /acute /mu 183
/periodcentered /cedilla /onesuperior /ordmasculine 188 /onequarter
/onehalf /threequarters 192 /Agrave /Aacute /Acircumflex /Atilde
/Adieresis /Aring /AE /Ccedilla /Egrave /Eacute /Ecircumflex
/Edieresis /Igrave /Iacute /Icircumflex /Idieresis /Eth /Ntilde
/Ograve /Oacute /Ocircumflex /Otilde /Odieresis /multiply /Oslash
/Ugrave /Uacute /Ucircumflex /Udieresis /Yacute /Thorn /germandbls
/agrave /aacute /acircumflex /atilde /adieresis /aring /ae /ccedilla
/egrave /eacute /ecircumflex /edieresis /igrave /iacute /icircumflex
/idieresis /eth /ntilde /ograve /oacute /ocircumflex /otilde
/odieresis /divide /oslash /ugrave /uacute /ucircumflex /udieresis
/yacute /thorn /ydieresis ]
>>
/PUT pdfmark
[ /_objdef {ZaDb}
  /type /dict
/OBJ pdfmark
[ {ZaDb}
  <<
   /Type /Font
   /Subtype /Type1
   /Name /ZaDb
   /BaseFont /ZapfDingbats
  >>
/PUT pdfmark
[ /_objdef {Helv}
  /type /dict
/OBJ pdfmark
[ {Helv}
  <<
  /Type /Font
  /Subtype /Type1
  /Name /Helv
  /BaseFont /Helvetica
  /Encoding {pdfDocEncoding}
  >>
/PUT pdfmark
[ /_objdef {aform}
  /type /dict
/OBJ pdfmark
[ /_objdef {afields}
  /type /array
/OBJ pdfmark
[/BBox [0 0 100 100] /_objdef {Check} /BP pdfmark
1 0 0 setrgbcolor /ZapfDingbats 80 selectfont 20 20 moveto (4) show
[/EP pdfmark
[/BBox [0 0 100 100] /_objdef {Cross} /BP pdfmark
1 0 0 setrgbcolor /ZapfDingbats 80 selectfont 20 20 moveto (8) show
[/EP pdfmark
[/BBox [0 0 250 100] /_objdef {Submit} /BP pdfmark 0.6 setgray 0 0 250
100 rectfill 1 setgray 2 2 moveto 2 98 lineto 248 98 lineto 246 96
lineto 4 96 lineto 4 4 lineto fill 0.34 setgray 248 98 moveto 248 2
lineto 2 2 lineto 4 4 lineto 246 4 lineto 246 96 lineto fill
/Helvetica 76 selectfont 0 setgray 8 22.5 moveto (Submit) show
[/EP pdfmark
[/BBox [0 0 250 100] /_objdef {SubmitP} /BP pdfmark 0.6 setgray 0 0
250 100 rectfill 0.34 setgray 2 2 moveto 2 98 lineto 248 98 lineto 246
96 lineto 4 96 lineto 4 4 lineto fill 1 setgray 248 98 moveto 248 2
lineto 2 2 lineto 4 4 lineto 246 4 lineto 246 96 lineto fill
/Helvetica 76 selectfont 0 setgray 10 20.5 moveto (Submit) show
[/EP pdfmark
[ {aform}
  <<
    /Fields {afields}
    /DR << /Font << /ZaDb {ZaDb} /Helv {Helv} >> >>
    /DA (/Helv 10 Tf 0 g )
    /NeedAppearances true
  >>
/PUT pdfmark
[ \string{Catalog\string}
  <<
    /AcroForm {aform}
  >>
/PUT pdfmark
}}%
 \setkeys{Form}{#1}%
}
\def\@endForm{}
\def\@Gauge[#1]#2#3#4{% parameters, label, minimum, maximum
  \typeout{Sorry, pdfmark drivers do not support FORM gauges}%
}
\def\@TextField[#1]#2{% parameters, label
 \def\Fld@name{#2}%
 \def\Fld@default{}%
 \let\Fld@value\@empty
 \def\Fld@width{\DefaultWidthofText}%
 \def\Fld@height{\DefaultHeightofText}%
 \bgroup
 \Field@toks={ }%
 \setkeys{Field}{#1}%
 \ifFld@hidden\def\Fld@width{1sp}\fi
 \ifx\Fld@value\@empty\def\Fld@value{\Fld@default}\fi
 \ifFld@multiline
  \def\Fld@height{4\DefaultHeightofText}%
 \fi
 \LayoutTextField{#2}{%
 \pdfmark[\MakeTextField{\Fld@width}{\Fld@height}]{%
 pdfmark=/ANN,Raw={\PDFForm@Text}}}%
 \egroup
}
\def\@ChoiceMenu[#1]#2#3{% parameters, label, choices
 \def\Fld@name{#2}%
 \def\Fld@default{}%
 \def\Fld@width{\DefaultWidthofChoiceMenu}%
 \def\Fld@height{\DefaultHeightofChoiceMenu}%
 \bgroup
 \Fld@menulength=0
 \@tempdima\z@
 \@for\@curropt:=#3\do{
    \expandafter\Fld@checkequals\@curropt==\\%
    \advance\Fld@menulength by 1
    \settowidth{\@tempdimb}{\@currDisplay}%
    \ifdim\@tempdimb>\@tempdima\@tempdima\@tempdimb\fi
  }%
 \advance\@tempdima by 15\p@
 \Field@toks={ }%
 \setkeys{Field}{#1}%
 \ifFld@hidden\def\Fld@width{1sp}\fi
 \LayoutChoiceField{#2}{%
 \ifFld@radio
   \@@Radio{#3}%
 \else
   {%
   \ifdim\Fld@width<\@tempdima
      \ifdim\@tempdima<1cm\@tempdima1cm\fi
      \edef\Fld@width{\the\@tempdima}%
   \fi
   \def\Fld@flags{}%
   \ifFld@combo\def\Fld@flags{/Ff 917504}\fi
   \ifFld@popdown\def\Fld@flags{/Ff 131072}\fi
   \ifx\Fld@flags\@empty
        \@tempdima=\the\Fld@menulength\Fld@charsize
        \advance\@tempdima by 2\Fld@borderwidth bp
        \edef\Fld@height{\the\@tempdima}%
   \fi
   \@@Listbox{#3}%
   }}%
 \fi
 \egroup
}
\def\@@Radio#1{%
 \Fld@listcount=0
 \@for\@curropt:=#1\do{%
 \expandafter\Fld@checkequals\@curropt==\\%
 \advance\Fld@listcount by 1
 \@currDisplay\space\pdfmark[\MakeRadioField{\Fld@width}{\Fld@height}]{
   pdfmark=/ANN,Raw={\PDFForm@Radio
      /AP <<
                /N <<
                 /\@currValue\space {Check}
                >>
        >>
   }} }% deliberate space between radio buttons
}
\newcount\Fld@listcount
\def\@@Listbox#1{%
 \Choice@toks={ }%
 \Fld@listcount=0
 \@for\@curropt:=#1\do{%
   \expandafter\Fld@checkequals\@curropt==\\%
   \advance\Fld@listcount by 1
   \edef\@processme{%
        \Choice@toks{\the\Choice@toks [(\@currValue) (\@currDisplay)]}%
   }\@processme
  }%
 \pdfmark[\MakeChoiceField{\Fld@width}{\Fld@height}]{
   pdfmark=/ANN,Raw={\PDFForm@List}}%
}
\def\@PushButton[#1]#2{% parameters, label
 \def\Fld@name{#2}%
 \bgroup
 \Field@toks={ }%
 \setkeys{Field}{#1}%
 \ifFld@hidden\def\Fld@width{1sp}\fi
 \LayoutPushButtonField{%
 \pdfmark[\MakeButtonField{#2}]{
   pdfmark=/ANN,Raw={
    \PDFForm@Push
}}}%
 \egroup
}
\def\@Submit[#1]#2{%
 \Field@toks={ }%
 \def\Fld@width{\DefaultWidthofSubmit}%
 \def\Fld@height{\DefaultHeightofSubmit}%
 \bgroup
 \def\Fld@name{Submit}%
 \setkeys{Field}{#1}%
 \ifFld@hidden\def\Fld@width{1sp}\fi
 \pdfmark[\MakeButtonField{#2}]{
   pdfmark=/ANN,Raw={\PDFForm@Submit
    /AP << /N {Submit} /D {SubmitP} >>
}}%
\egroup
}
\def\@Reset[#1]#2{%
 \Field@toks={ }%
 \def\Fld@width{\DefaultWidthofReset}%
 \def\Fld@height{\DefaultHeightofReset}%
 \bgroup
 \def\Fld@name{Reset}%
 \setkeys{Field}{#1}%
 \ifFld@hidden\def\Fld@width{1sp}\fi
 \pdfmark[\MakeButtonField{#2}]{%
  pdfmark=/ANN,Raw={\PDFForm@Reset}}%
 \egroup
}
\def\@CheckBox[#1]#2{% parameters, label
 \def\Fld@name{#2}%
 \def\Fld@default{0}%
 \bgroup
 \def\Fld@width{\DefaultWidthofCheckBox}%
 \def\Fld@height{\DefaultHeightofCheckBox}%
 \Field@toks={ }%
 \setkeys{Field}{#1}%
 \ifFld@hidden\def\Fld@width{1sp}\fi
 \LayoutCheckField{#2}{%
 \pdfmark[\MakeCheckField{\Fld@width}{\Fld@height}]{%
  pdfmark=/ANN,Raw={\PDFForm@Check}}}%
\egroup
}
\def\PDFForm@Check{
         /Subtype /Widget
\ifFld@hidden /F 6 \else /F 4 \fi
        /T (\Fld@name)
        /Q \Fld@align\space
        /BS << /W \Fld@borderwidth\space /S /\Fld@borderstyle\space >>
        /MK <<
             /BC [ \Fld@bordercolor\space]
\ifx\Fld@bcolor\@empty
 \else
             /BG [ \Fld@bcolor\space]
\fi
             /CA (H)
            >>
        /DA (/ZaDb \strip@pt\Fld@charsize\space Tf \Fld@color\space rg)
        /FT /Btn
        /H /P
   \ifFld@checked /V /Yes \else /V /Off \fi
}
\def\PDFForm@Push{
        /Subtype /Widget
\ifFld@hidden    /F 6 \else /F 4 \fi
        /T (\Fld@name)
        /FT /Btn
        /Ff 65540
        /H /P
        /BS << /W \Fld@borderwidth\space /S /\Fld@borderstyle\space >>
        /MK <<
             /BC [ \Fld@bordercolor\space]
            >>
        /A << /S /JavaScript /JS (\Fld@onclick;) >>
}
\def\PDFForm@List{        /Subtype /Widget
\ifFld@hidden    /F 6 \else /F 4 \fi
        /T (\Fld@name)
        /FT /Ch
        /Q \Fld@align\space
        /BS << /W \Fld@borderwidth\space /S /\Fld@borderstyle\space >>
        /MK <<
             /BC [ \Fld@bordercolor\space]
\ifx\Fld@bcolor\@empty
 \else
             /BG [ \Fld@bcolor\space]
\fi
            >>
        /DA (/Helv \strip@pt\Fld@charsize\space Tf \Fld@color\space rg )
        /Opt [ \the\Choice@toks ]
        /DV (\Fld@default)
        \Fld@flags
}
\def\PDFForm@Radio{
        /Subtype /Widget
\ifFld@hidden    /F 6 \else /F 4 \fi
        /T (\Fld@name)
        /FT /Btn
        /Ff 49152
        /H /P
        /BS << /W \Fld@borderwidth\space /S /\Fld@borderstyle\space >>
        /MK <<
             /BC [ \Fld@bordercolor\space]
\ifx\Fld@bcolor\@empty
 \else
             /BG [ \Fld@bcolor\space]
\fi
     /CA (H)
            >>
        /DA (/ZaDb \strip@pt\Fld@charsize\space Tf \Fld@color\space rg)
  \ifx\@currValue\Fld@default
        /V /\Fld@default\space
  \else
        /V /Off
  \fi
}
\def\PDFForm@Text{
        /Subtype /Widget
\ifFld@hidden    /F 6 \else /F 4 \fi
        /T (\Fld@name)
        /Q \Fld@align\space
        /FT /Tx
        /BS << /W \Fld@borderwidth\space /S /\Fld@borderstyle\space >>
        /MK <<
             /BC [ \Fld@bordercolor\space]
\ifx\Fld@bcolor\@empty
 \else
             /BG [ \Fld@bcolor\space]
\fi
            >>
        /DA (/Helv \strip@pt\Fld@charsize\space Tf \Fld@color\space rg )
        /DV (\Fld@default)
/AA <<
\ifx\Fld@keystroke@code\@empty\else
 /K << /S /JavaScript /JS (\Fld@keystroke@code) >>
\fi
\ifx\Fld@format@code\@empty\else
 /F << /S /JavaScript /JS (\Fld@format@code) >>
\fi
\ifx\Fld@validate@code\@empty\else
 /V << /S /JavaScript /JS (\Fld@validate@code) >>
\fi
\ifx\Fld@calculate@code\@empty\else
 /C << /S /JavaScript /JS (\Fld@calculate@code) >>
\fi
>>
        /V (\Fld@value)
 \ifFld@multiline
     \ifFld@readonly\Ff 4097 \else /Ff 4096 \fi
 \else
   \ifFld@password
     \ifFld@readonly\Ff 8193 \else /Ff 8192 \fi
    \fi
 \fi
 \ifnum\Fld@maxlen>0/MaxLen \Fld@maxlen \fi
}
\def\PDFForm@Submit{
        /Subtype /Widget
\ifFld@hidden    /F 6 \else /F 4 \fi
        /T (\Fld@name)
        /FT /Btn
        /Ff 65540
        /H /P
        /BS << /W \Fld@borderwidth\space /S /\Fld@borderstyle\space >>
        /MK <<
             /BC [ \Fld@bordercolor\space]
          >>
        /A <<
                /S /SubmitForm
                /F <<
                        /FS /URL
                        /F (\Form@action)
                >>
\ifForm@html /Flags 4 \fi
        >>
}
\def\PDFForm@Reset{
        /Subtype /Widget
\ifFld@hidden    /F 6 \else /F 4 \fi
        /T (\Fld@name)
        /FT /Btn
        /H /P
        /DA (/Helv \strip@pt\Fld@charsize\space Tf 0 0 1 rg)
        /Ff 65540
        /MK <<
             /BC [ \Fld@bordercolor\space]
          >>
        /BS << /W \Fld@borderwidth\space /S /\Fld@borderstyle\space >>
        /A << /S /ResetForm >>
}
\let\H@old@sect\@sect
\def\@sect#1#2#3#4#5#6[#7]#8{%
 \H@old@sect{#1}{#2}{#3}{#4}{#5}{#6}[{#7}]{#8}%
 \ifx\\#1\\\else
  \ifnum#2>\c@secnumdepth\else
    \ifhy@naturalnames
     \edef\@thishlabel{\csname the#1\endcsname}%
    \else
     \edef\@thishlabel{\csname theH#1\endcsname}%
    \fi
\@writetorep{\csname the#1\endcsname}{#7}{#1.\@thishlabel}{#2}\fi
 \fi
}
\let\H@old@part\@part
\def\@part[#1]#2{%
 \H@old@part[{#1}]{#2}%
 \ifhy@naturalnames
   \@writetorep{\thepart}{#1}{part.\thepart}{-1}%
 \else
   \@writetorep{\thepart}{#1}{part.\theHpart}{-1}%
 \fi
}
\let\H@old@chapter\@chapter
\def\@chapter[#1]#2{%
 \H@old@chapter[{#1}]{#2}%
 \ifhy@naturalnames
   \@writetorep{\thechapter}{#1}{chapter.\thechapter}{0}%
 \else
   \@writetorep{\thechapter}{#1}{chapter.\theHchapter}{0}%
 \fi
  }
\expandafter\def\csname Parent-4\endcsname{}
\expandafter\def\csname Parent-3\endcsname{}
\expandafter\def\csname Parent-2\endcsname{}
\expandafter\def\csname Parent-1\endcsname{}
\expandafter\def\csname Parent0\endcsname{}
\expandafter\def\csname Parent1\endcsname{}
\expandafter\def\csname Parent2\endcsname{}
\expandafter\def\csname Parent3\endcsname{}
\expandafter\def\csname Parent4\endcsname{}
\newwrite\@outlinefile
\def\@writetorep#1#2#3#4{\ifx\WriteBookmarks\relax{}%
    \else\@@writetorep{#1}{#2}{#3}{#4}\fi}
\def\@@writetorep#1#2#3#4{%
    \PDFbookmarktrue
    \@tempcnta#4
    \expandafter\xdef\csname Parent#4\endcsname{#3}%
    \advance\@tempcnta by -1
    \ifx\Hy@bookmarkstring\relax
        \Hy@PDFDef\Hy@bookmarkstring{#2}%
    \fi
    \Hy@PDFDef\@tempa{#1 }%
    \protected@write\@outlinefile%
    {%
       \expandafter\let\csname T1-cmd\endcsname\@gobble
       \let\@tabacckludge\@empty
       \let\IeC\@firstofone
    }{%
    \ifhy@bookmarksnumbered
      \protect\BOOKMARK[#4]{#3}%
       {\@tempa\Hy@bookmarkstring}{\csname Parent\the\@tempcnta\endcsname}%
    \else
      \protect\BOOKMARK[#4]{#3}%
       {\Hy@bookmarkstring}{\csname Parent\the\@tempcnta\endcsname}%
    \fi
    }%
    \PDFbookmarkfalse
    \global\let\Hy@bookmarkstring\relax
}
\let\Hy@bookmarkstring\relax
\newcommand*{\ifbookmark}{%
   \ifPDFbookmark
    \expandafter\@firstoftwo
   \else
     \expandafter\@secondoftwo
   \fi
}
\def\pdfbookmark{\@ifnextchar[{\pdf@bookmark}{\pdf@bookmark[0]}}
\def\pdf@bookmark[#1]#2#3{%
 \@writetorep{}{#2}{#3.#1}{#1}%
 \hyper@anchorstart{#3.#1}\hyper@anchorend
}
\def\BOOKMARK{\@ifnextchar[{\@BOOKMARK}{\@BOOKMARK[1]}}
\def\ReadBookmarks{%
  \begingroup
  \escapechar=`\\%
  \let\escapechar\@gobble %
  \def\@BOOKMARK [##1]##2##3##4{\calc@bm@number{##4}}%
  \InputIfFileExists{\jobname.out}{}{}%
  \ifx\WriteBookmarks\relax\global\let\WriteBookmarks\relax\fi
  \def\@BOOKMARK[##1]##2##3##4{%
   \def\@tempx{##3}%
 \pdfmark{pdfmark=/OUT,Count=\@bookmarkopenstatus\check@bm@number{##2},
    Dest=##2,Title=\expandafter\strip@prefix\meaning\@tempx}%
   }%
   {%
    \def\WriteBookmarks{0}%
    \InputIfFileExists{\jobname.out}{}{}%
   }%
   %{\escapechar\m@ne\InputIfFileExists{\jobname.out}{}{}}%
   \ifx\WriteBookmarks\relax\else
     \immediate\openout\@outlinefile=\jobname.out
   \fi
   \endgroup
}
\def\check@bm@number#1{\expandafter \ifx\csname#1\endcsname \relax 0%
    \else \csname#1\endcsname \fi}
\def\calc@bm@number#1{\@tempcnta=\check@bm@number{#1}\relax
    \advance\@tempcnta by1
    \expandafter\xdef\csname#1\endcsname{\the\@tempcnta}}
\begingroup
  \catcode`P=12
  \catcode`T=12
  \lowercase{\endgroup
\gdef\rem@ptetc#1.#2PT#3!{#1\ifnum#2>\z@.#2\fi}}
\def\strip@pt@and@otherjunk#1{\expandafter\rem@ptetc\the#1!}
\endinput
%%
%% End of file `pdfmark.def'.
