%%
%% This is file `amigapl.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% strony.dtx  (with options: `amigapl')
%% 
%% IMPORTANT NOTICE:
%% 
%% For the copyright see the source file.
%% 
%% Any modified versions of this file must be renamed
%% with new filenames distinct from amigapl.def.
%% 
%% For distribution of the original source see the terms
%% for copying and modification in the file strony.dtx.
%% 
%% This generated file may be distributed as long as the
%% original source files, as listed above, are part of the
%% same distribution. (The sources need not necessarily be
%% in the same archive or directory.)
\ProvidesFile{amigapl.def}
\DeclareInputText{194}{\k A}
\DeclareInputText{202}{\@tabacckludge'C}
\DeclareInputText{203}{\k E}
\DeclareInputText{206}{\L}
\DeclareInputText{207}{\@tabacckludge'N}
\DeclareInputText{211}{\@tabacckludge'O}
\DeclareInputText{212}{\@tabacckludge'S}
\DeclareInputText{218}{\@tabacckludge'Z}
\DeclareInputText{219}{\.Z}
\DeclareInputText{226}{\k a}
\DeclareInputText{234}{\@tabacckludge'c}
\DeclareInputText{235}{\k e}
\DeclareInputText{238}{\l}
\DeclareInputText{239}{\@tabacckludge'n}
\DeclareInputText{243}{\@tabacckludge'o}
\DeclareInputText{244}{\@tabacckludge's}
\DeclareInputText{250}{\@tabacckludge'z}
\DeclareInputText{251}{\.z}
\endinput
%%
%% End of file `amigapl.def'.
