%%
%% This is file `hpdftex.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% hyperref.dtx  (with options: `pdftex,pdfform,outlines')
%% 
%% File: hyperref.dtx Copyright (C) 1995, 1996, 1997, 1998 Sebastian Rahtz

\providecommand\@pdfview{XYZ}
\def\new@pdflink#1{%
 \ifhy@verbose\typeout{pdftex: define anchor #1}\fi
 \pdfdest name {#1}\@pdfview\ifvmode\nobreak\fi
}
\let\pdf@endanchor\@empty
\AtBeginDocument{%
  \ifhy@colorlinks
   \def\pdfBorderAttrs{/Border [0 0 0]}%
  \fi
}
\def\@pdfborder{0 0 1}%
\def\pdfBorderAttrs{/Border [\@pdfborder]}
\def\find@pdflink#1#2{%
  \leavevmode\pdfannotlink
  attr{\pdfBorderAttrs /H \@pdfhighlight /C [\CurrentBorderColor]}
  goto name {#2}%
  \hy@colorlink{\csname @#1color\endcsname}%
}
\def\close@pdflink{\hy@endcolorlink\pdfendlink}
\def\hyper@anchor#1{\new@pdflink{#1}\anchor@spot\pdf@endanchor}
\def\hyper@anchorstart#1{\new@pdflink{#1}\hy@activeanchortrue}
\def\hyper@anchorend{\pdf@endanchor\hy@activeanchorfalse}
\def\hyper@linkstart#1#2{%
  \edef\CurrentBorderColor{\csname @#1bordercolor\endcsname}%
  \find@pdflink{#1}{#2}}
\def\hyper@linkend{\close@pdflink}
\def\hyper@link#1#2#3{%
    \edef\CurrentBorderColor{\csname @#1bordercolor\endcsname}%
    \find@pdflink{#1}{#2}#3\close@pdflink
}
\def\CurrentBorderColor{\@linkbordercolor}
\def\hyper@linkurl#1#2{%
   \bgroup
   \hyper@chars
   \leavevmode\pdfannotlink
   attr{\pdfBorderAttrs /H \@pdfhighlight /C [\@urlbordercolor]}
   user{/Subtype /Link
    /A <<
        /Type /Action
        /S /URI
        /URI (#2)
    >>}\hy@colorlink{\@urlcolor}#1%
   \close@pdflink
   \egroup
}
\def\hyper@linkfile#1#2#3{% anchor text, filename, linkname
   \bgroup
   \leavevmode\pdfannotlink
   attr{\pdfBorderAttrs\space /H \@pdfhighlight\space /C [\@filebordercolor]}
   user {/Subtype /Link
         /A <<   /F (#2) /S /GoToR
         \ifhy@newwindow /NewWindow true \fi
         \ifx\\#3\\/D [0 \@pdfstartview] \else /D (#3)\fi
         \space>>}\hy@colorlink{\@filecolor}#1\close@pdflink
   \egroup
}
\ifx\pdftexversion\@undefined
  \def\@pdfproducer{pdfTeX}
\else
  \def\@pdfproducer{pdfTeX\the\pdftexversion.\pdftexrevision}
\fi
\def\PDF@SetupDoc{%
  \ifx\@pdfpagescrop\@empty\else
    \edef\process@me{\pdfpagesattr={/CropBox [\@pdfpagescrop]}}%
    \process@me
  \fi
  \pdfcatalog {            % Catalog dictionary of PDF output.
    /PageMode \@pdfpagemode
    /URI << /Base (\@baseurl) >>
\ifhy@acrofour
   /PageLabels << /Nums [ 0 << /S /D /St \c@page\space >> ] >>
\fi
    }
\ifx\@pdfstartview\@empty
\else
  openaction goto page \@pdfstartpage {\@pdfstartview}%
\fi
\pdfcatalog{
/ViewerPreferences <<
 \ifhy@toolbar\else /HideToolbar true \fi
 \ifhy@menubar\else /HideMenubar true \fi
 \ifhy@windowui\else /HideWindowUI true \fi
 \ifhy@fitwindow /FitWindow true \fi
 \ifhy@centerwindow /CenterWindow true \fi
   >>
 \ifx\pdf@pagelayout\@empty\else/PageLayout /\pdf@pagelayout\space\fi
}%
}
\def\PDF@FinishDoc{
 \pdfinfo {
  /Author (\@pdfauthor)
  /Title (\@pdftitle)
  /Subject (\@pdfsubject)
  /Creator (\@pdfcreator)
  /Producer (\@pdfproducer)
  /Keywords (\@pdfkeywords)
  }%
}
\def\hyper@pagetransition{%
 \ifx\@pdfpagetransition\@empty
 \else
   \edef\@processme{%
\global\pdfpageattr{/Trans << /S /\@pdfpagetransition\space >>}}%
   \@processme
 \fi
}
\pdfoutput=1
\pdfcompresslevel=9
\AtBeginDocument{%
 \pdfpagewidth\paperwidth
 \pdfpageheight\paperheight
}
\def\Acrobatmenu#1#2{%
   \leavevmode\pdfannotlink
   attr{\pdfBorderAttrs /H \@pdfhighlight /C [\@menubordercolor]}
   user{
    /Subtype /Link
    /A <<
       /S /Named /N /#1
    >>
    /H \@pdfhighlight
    }\hy@colorlink{\@menucolor}#2\close@pdflink
}
\def\@Gauge[#1]#2#3#4{% parameters, label, minimum, maximum
  \typeout{Sorry, pdftex does not support FORM gauges}%
}
\RequirePackage{pifont}%
\def\MakeFieldObject#1#2{\setbox0=\hbox{#1}%
 \pdfform0%
 \expandafter\edef\csname #2Object\endcsname{\the\pdflastform\space 0 R}%
 \hbox to 0pt{\hskip-\maxdimen{\pdfrefform \the\pdflastform}}%
}%
\def\@Form[#1]{%
 \@ifundefined{textcolor}{\let\textcolor\@gobble}{}
 \setkeys{Form}{#1}%
 \pdfcatalog{/AcroForm \OBJ@acroform\space 0 R}%
 \MakeFieldObject{\ding{123}}{Ding}%
 \MakeFieldObject{\fbox{\textcolor{yellow}{\textsf{Submit}}}}{Submit}%
 \MakeFieldObject{\fbox{\textcolor{yellow}{\textsf{SubmitP}}}}{SubmitP}%
}
\def\@endForm{}
\def\@Gauge[#1]#2#3#4{% parameters, label, minimum, maximum
  \typeout{Sorry, pdfmark drivers do not support FORM gauges}%
}
\def\@TextField[#1]#2{% parameters, label
 \def\Fld@name{#2}%
 \def\Fld@default{}%
 \let\Fld@value\@empty
 \def\Fld@width{\DefaultWidthofText}%
 \def\Fld@height{\DefaultHeightofText}%
 \bgroup
 \Field@toks={ }%
 \setkeys{Field}{#1}%
 \ifFld@hidden\def\Fld@width{1sp}\fi
 \ifx\Fld@value\@empty\def\Fld@value{\Fld@default}\fi
 \ifFld@multiline
  \def\Fld@height{4\DefaultHeightofText}%
 \fi
 \LayoutTextField{#2}{%
 \pdfannotlink user {\PDFForm@Text}%
 \MakeTextField{\Fld@width}{\Fld@height}\pdfendlink}%
\egroup
}
\def\@ChoiceMenu[#1]#2#3{% parameters, label, choices
 \def\Fld@name{#2}%
 \def\Fld@default{}%
 \def\Fld@width{\DefaultWidthofChoiceMenu}%
 \def\Fld@height{\DefaultHeightofChoiceMenu}%
 \bgroup
 \Fld@menulength=0
 \@tempdima\z@
 \@for\@curropt:=#3\do{
    \expandafter\Fld@checkequals\@curropt==\\%
    \advance\Fld@menulength by 1
    \settowidth{\@tempdimb}{\@currDisplay}%
    \ifdim\@tempdimb>\@tempdima\@tempdima\@tempdimb\fi
  }%
 \advance\@tempdima by 15\p@
 \Field@toks={ }%
 \setkeys{Field}{#1}%
 \ifFld@hidden\def\Fld@width{1sp}\fi
 \LayoutChoiceField{#2}{%
 \ifFld@radio
   \@@Radio{#3}%
 \else
   {%
   \ifdim\Fld@width<\@tempdima
      \ifdim\@tempdima<1cm\@tempdima1cm\fi
      \edef\Fld@width{\the\@tempdima}%
   \fi
   \def\Fld@flags{}%
   \ifFld@combo\def\Fld@flags{/Ff 917504}\fi
   \ifFld@popdown\def\Fld@flags{/Ff 131072}\fi
   \ifx\Fld@flags\@empty
        \@tempdima=\the\Fld@menulength\Fld@charsize
        \advance\@tempdima by 2\Fld@borderwidth bp
        \edef\Fld@height{\the\@tempdima}%
   \fi
   \@@Listbox{#3}%
   }}%
 \fi
 \egroup
}
\def\@@Radio#1{%
 \Fld@listcount=0
 \@for\@curropt:=#1\do{%
 \expandafter\Fld@checkequals\@curropt==\\%
 \advance\Fld@listcount by 1
 \@currDisplay\space
 \leavevmode\pdfannotlink user {\PDFForm@Radio
    /AP <<
           /N <<
/\@currValue\space \DingObject
              >>
        >>
    }%
   \MakeRadioField{\Fld@width}{\Fld@height}\pdfendlink
   \space}% deliberate space between radio buttons
}
\newcount\Fld@listcount
\def\@@Listbox#1{%
 \Choice@toks={ }%
 \Fld@listcount=0
 \@for\@curropt:=#1\do{%
   \expandafter\Fld@checkequals\@curropt==\\%
   \advance\Fld@listcount by 1
   \edef\@processme{%
        \Choice@toks{\the\Choice@toks [(\@currValue) (\@currDisplay)]}%
   }\@processme
  }%
 \leavevmode\pdfannotlink user {\PDFForm@List}%
 \MakeChoiceField{\Fld@width}{\Fld@height}\pdfendlink
}
\def\@PushButton[#1]#2{% parameters, label
 \def\Fld@name{#2}%
 \bgroup
 \Field@toks={ }%
 \setkeys{Field}{#1}%
 \ifFld@hidden\def\Fld@width{1sp}\fi
 \LayoutPushButtonField{\leavevmode\pdfannotlink user {\PDFForm@Push}%
 \MakeButtonField{#2}\pdfendlink}%
 \egroup
}
\def\@Submit[#1]#2{%
 \Field@toks={ }%
 \def\Fld@width{\DefaultWidthofSubmit}%
 \def\Fld@height{\DefaultHeightofSubmit}%
 \bgroup
 \def\Fld@name{Submit}%
 \setkeys{Field}{#1}%
 \ifFld@hidden\def\Fld@width{1sp}\fi
  \leavevmode\pdfannotlink user {\PDFForm@Submit
    /AP << /N \SubmitObject\space /D \SubmitPObject >>
}\MakeButtonField{#2}\pdfendlink
\egroup
}
\def\@Reset[#1]#2{%
 \Field@toks={ }%
 \def\Fld@width{\DefaultWidthofReset}%
 \def\Fld@height{\DefaultHeightofReset}%
 \bgroup
 \def\Fld@name{Reset}%
 \setkeys{Field}{#1}%
 \ifFld@hidden\def\Fld@width{1sp}\fi
 \leavevmode\pdfannotlink user {\PDFForm@Reset}%
 \MakeButtonField{#2}\pdfendlink
 \egroup
}
\def\@CheckBox[#1]#2{% parameters, label
 \def\Fld@name{#2}%
 \def\Fld@default{0}%
 \bgroup
 \def\Fld@width{\DefaultWidthofCheckBox}%
 \def\Fld@height{\DefaultHeightofCheckBox}%
 \Field@toks={ }%
 \setkeys{Field}{#1}%
 \ifFld@hidden\def\Fld@width{1sp}\fi
 \LayoutCheckField{#2}{%
 \pdfannotlink user {\PDFForm@Check}%
 \MakeCheckField{\Fld@width}{\Fld@height}\pdfendlink}\egroup
}
\pdfobj { << /Type /Encoding
/Differences [ 24 /breve /caron /circumflex /dotaccent /hungarumlaut
/ogonek /ring /tilde 39 /quotesingle 96 /grave 128 /bullet /dagger /daggerdbl                 /ellipsis /emdash /endash /florin /fraction /guilsinglleft
/guilsinglright /minus /perthousand /quotedblbase /quotedblleft
/quotedblright /quoteleft  /quoteright /quotesinglbase /trademark /fi /fl /Lslash /OE
/Scaron /Ydieresis /Zcaron /dotlessi /lslash /oe /scaron /zcaron
164 /currency 166 /brokenbar 168 /dieresis /copyright /ordfeminine 172
/logicalnot /.notdef /registered /macron /degree /plusminus
/twosuperior /threesuperior /acute /mu 183 /periodcentered /cedilla /onesuperior
/ordmasculine 188 /onequarter /onehalf /threequarters 192 /Agrave /Aacute
/Acircumflex /Atilde /Adieresis /Aring /AE /Ccedilla /Egrave /Eacute
/Ecircumflex /Edieresis /Igrave /Iacute /Icircumflex /Idieresis /Eth /Ntilde                 /Ograve /Oacute /Ocircumflex /Otilde /Odieresis /multiply
/Oslash /Ugrave /Uacute /Ucircumflex /Udieresis /Yacute /Thorn
/germandbls /agrave /aacute /acircumflex /atilde /adieresis /aring /ae
/ccedilla /egrave /eacute /ecircumflex /edieresis /igrave /iacute
/icircumflex /idieresis /eth /ntilde /ograve /oacute /ocircumflex
/otilde /odieresis /divide /oslash /ugrave /uacute /ucircumflex /udieresis /yacute /thorn /ydieresis ]
>> }
\edef\OBJ@pdfdocencoding{\the\pdflastobj}

\pdfobj {
  <<
   /Type /Font
   /Subtype /Type1
   /Name /ZaDb
   /BaseFont /ZapfDingbats
>>
}
\edef\OBJ@ZaDb{\the\pdflastobj}

\pdfobj {  <<
  /Type /Font
  /Subtype /Type1
  /Name /Helv
  /BaseFont /Helvetica
  /Encoding \OBJ@pdfdocencoding\space 0 R
  >>
}
\edef\OBJ@Helv{\the\pdflastobj}

\pdfobj {
  <<
    /Fields []
    /DR << /Font << /ZaDb \OBJ@ZaDb\space 0 R /Helv \OBJ@Helv\space0 R >> >>
    /DA (/Helv 10 Tf 0 g )
    /NeedAppearances true
  >>
}
\edef\OBJ@acroform{\the\pdflastobj}
\def\PDFForm@Check{
         /Subtype /Widget
\ifFld@hidden /F 6 \else /F 4 \fi
        /T (\Fld@name)
        /Q \Fld@align\space
        /BS << /W \Fld@borderwidth\space /S /\Fld@borderstyle\space >>
        /MK <<
             /BC [ \Fld@bordercolor\space]
\ifx\Fld@bcolor\@empty
 \else
             /BG [ \Fld@bcolor\space]
\fi
             /CA (H)
            >>
        /DA (/ZaDb \strip@pt\Fld@charsize\space Tf \Fld@color\space rg)
        /FT /Btn
        /H /P
   \ifFld@checked /V /Yes \else /V /Off \fi
}
\def\PDFForm@Push{
        /Subtype /Widget
\ifFld@hidden    /F 6 \else /F 4 \fi
        /T (\Fld@name)
        /FT /Btn
        /Ff 65540
        /H /P
        /BS << /W \Fld@borderwidth\space /S /\Fld@borderstyle\space >>
        /MK <<
             /BC [ \Fld@bordercolor\space]
            >>
        /A << /S /JavaScript /JS (\Fld@onclick;) >>
}
\def\PDFForm@List{        /Subtype /Widget
\ifFld@hidden    /F 6 \else /F 4 \fi
        /T (\Fld@name)
        /FT /Ch
        /Q \Fld@align\space
        /BS << /W \Fld@borderwidth\space /S /\Fld@borderstyle\space >>
        /MK <<
             /BC [ \Fld@bordercolor\space]
\ifx\Fld@bcolor\@empty
 \else
             /BG [ \Fld@bcolor\space]
\fi
            >>
        /DA (/Helv \strip@pt\Fld@charsize\space Tf \Fld@color\space rg )
        /Opt [ \the\Choice@toks ]
        /DV (\Fld@default)
        \Fld@flags
}
\def\PDFForm@Radio{
        /Subtype /Widget
\ifFld@hidden    /F 6 \else /F 4 \fi
        /T (\Fld@name)
        /FT /Btn
        /Ff 49152
        /H /P
        /BS << /W \Fld@borderwidth\space /S /\Fld@borderstyle\space >>
        /MK <<
             /BC [ \Fld@bordercolor\space]
\ifx\Fld@bcolor\@empty
 \else
             /BG [ \Fld@bcolor\space]
\fi
     /CA (H)
            >>
        /DA (/ZaDb \strip@pt\Fld@charsize\space Tf \Fld@color\space rg)
  \ifx\@currValue\Fld@default
        /V /\Fld@default\space
  \else
        /V /Off
  \fi
}
\def\PDFForm@Text{
        /Subtype /Widget
\ifFld@hidden    /F 6 \else /F 4 \fi
        /T (\Fld@name)
        /Q \Fld@align\space
        /FT /Tx
        /BS << /W \Fld@borderwidth\space /S /\Fld@borderstyle\space >>
        /MK <<
             /BC [ \Fld@bordercolor\space]
\ifx\Fld@bcolor\@empty
 \else
             /BG [ \Fld@bcolor\space]
\fi
            >>
        /DA (/Helv \strip@pt\Fld@charsize\space Tf \Fld@color\space rg )
        /DV (\Fld@default)
/AA <<
\ifx\Fld@keystroke@code\@empty\else
 /K << /S /JavaScript /JS (\Fld@keystroke@code) >>
\fi
\ifx\Fld@format@code\@empty\else
 /F << /S /JavaScript /JS (\Fld@format@code) >>
\fi
\ifx\Fld@validate@code\@empty\else
 /V << /S /JavaScript /JS (\Fld@validate@code) >>
\fi
\ifx\Fld@calculate@code\@empty\else
 /C << /S /JavaScript /JS (\Fld@calculate@code) >>
\fi
>>
        /V (\Fld@value)
 \ifFld@multiline
     \ifFld@readonly\Ff 4097 \else /Ff 4096 \fi
 \else
   \ifFld@password
     \ifFld@readonly\Ff 8193 \else /Ff 8192 \fi
    \fi
 \fi
 \ifnum\Fld@maxlen>0/MaxLen \Fld@maxlen \fi
}
\def\PDFForm@Submit{
        /Subtype /Widget
\ifFld@hidden    /F 6 \else /F 4 \fi
        /T (\Fld@name)
        /FT /Btn
        /Ff 65540
        /H /P
        /BS << /W \Fld@borderwidth\space /S /\Fld@borderstyle\space >>
        /MK <<
             /BC [ \Fld@bordercolor\space]
          >>
        /A <<
                /S /SubmitForm
                /F <<
                        /FS /URL
                        /F (\Form@action)
                >>
\ifForm@html /Flags 4 \fi
        >>
}
\def\PDFForm@Reset{
        /Subtype /Widget
\ifFld@hidden    /F 6 \else /F 4 \fi
        /T (\Fld@name)
        /FT /Btn
        /H /P
        /DA (/Helv \strip@pt\Fld@charsize\space Tf 0 0 1 rg)
        /Ff 65540
        /MK <<
             /BC [ \Fld@bordercolor\space]
          >>
        /BS << /W \Fld@borderwidth\space /S /\Fld@borderstyle\space >>
        /A << /S /ResetForm >>
}
\let\H@old@sect\@sect
\def\@sect#1#2#3#4#5#6[#7]#8{%
 \H@old@sect{#1}{#2}{#3}{#4}{#5}{#6}[{#7}]{#8}%
 \ifx\\#1\\\else
  \ifnum#2>\c@secnumdepth\else
    \ifhy@naturalnames
     \edef\@thishlabel{\csname the#1\endcsname}%
    \else
     \edef\@thishlabel{\csname theH#1\endcsname}%
    \fi
\@writetorep{\csname the#1\endcsname}{#7}{#1.\@thishlabel}{#2}\fi
 \fi
}
\let\H@old@part\@part
\def\@part[#1]#2{%
 \H@old@part[{#1}]{#2}%
 \ifhy@naturalnames
   \@writetorep{\thepart}{#1}{part.\thepart}{-1}%
 \else
   \@writetorep{\thepart}{#1}{part.\theHpart}{-1}%
 \fi
}
\let\H@old@chapter\@chapter
\def\@chapter[#1]#2{%
 \H@old@chapter[{#1}]{#2}%
 \ifhy@naturalnames
   \@writetorep{\thechapter}{#1}{chapter.\thechapter}{0}%
 \else
   \@writetorep{\thechapter}{#1}{chapter.\theHchapter}{0}%
 \fi
  }
\expandafter\def\csname Parent-4\endcsname{}
\expandafter\def\csname Parent-3\endcsname{}
\expandafter\def\csname Parent-2\endcsname{}
\expandafter\def\csname Parent-1\endcsname{}
\expandafter\def\csname Parent0\endcsname{}
\expandafter\def\csname Parent1\endcsname{}
\expandafter\def\csname Parent2\endcsname{}
\expandafter\def\csname Parent3\endcsname{}
\expandafter\def\csname Parent4\endcsname{}
\newwrite\@outlinefile
\def\@writetorep#1#2#3#4{\ifx\WriteBookmarks\relax{}%
    \else\@@writetorep{#1}{#2}{#3}{#4}\fi}
\def\@@writetorep#1#2#3#4{%
    \PDFbookmarktrue
    \@tempcnta#4
    \expandafter\xdef\csname Parent#4\endcsname{#3}%
    \advance\@tempcnta by -1
    \ifx\Hy@bookmarkstring\relax
        \Hy@PDFDef\Hy@bookmarkstring{#2}%
    \fi
    \Hy@PDFDef\@tempa{#1 }%
    \protected@write\@outlinefile%
    {%
       \expandafter\let\csname T1-cmd\endcsname\@gobble
       \let\@tabacckludge\@empty
       \let\IeC\@firstofone
    }{%
    \ifhy@bookmarksnumbered
      \protect\BOOKMARK[#4]{#3}%
       {\@tempa\Hy@bookmarkstring}{\csname Parent\the\@tempcnta\endcsname}%
    \else
      \protect\BOOKMARK[#4]{#3}%
       {\Hy@bookmarkstring}{\csname Parent\the\@tempcnta\endcsname}%
    \fi
    }%
    \PDFbookmarkfalse
    \global\let\Hy@bookmarkstring\relax
}
\let\Hy@bookmarkstring\relax
\newcommand*{\ifbookmark}{%
   \ifPDFbookmark
    \expandafter\@firstoftwo
   \else
     \expandafter\@secondoftwo
   \fi
}
\def\pdfbookmark{\@ifnextchar[{\pdf@bookmark}{\pdf@bookmark[0]}}
\def\pdf@bookmark[#1]#2#3{%
 \@writetorep{}{#2}{#3.#1}{#1}%
 \hyper@anchorstart{#3.#1}\hyper@anchorend
}
\def\BOOKMARK{\@ifnextchar[{\@BOOKMARK}{\@BOOKMARK[1]}}
\def\ReadBookmarks{%
  \begingroup
  \escapechar=`\\%
  \let\escapechar\@gobble %
  \def\@BOOKMARK [##1]##2##3##4{\calc@bm@number{##4}}%
  \InputIfFileExists{\jobname.out}{}{}%
  \ifx\WriteBookmarks\relax\global\let\WriteBookmarks\relax\fi
  \def\@BOOKMARK[##1]##2##3##4{%
   \def\@tempx{##3}%
   \pdfoutline goto
 name{##2}%
    count\@bookmarkopenstatus\check@bm@number{##2}{%
   \expandafter\strip@prefix\meaning\@tempx}%
   }%
   {%
    \def\WriteBookmarks{0}%
    \InputIfFileExists{\jobname.out}{}{}%
   }%
   %{\escapechar\m@ne\InputIfFileExists{\jobname.out}{}{}}%
   \ifx\WriteBookmarks\relax\else
     \immediate\openout\@outlinefile=\jobname.out
   \fi
   \endgroup
}
\def\check@bm@number#1{\expandafter \ifx\csname#1\endcsname \relax 0%
    \else \csname#1\endcsname \fi}
\def\calc@bm@number#1{\@tempcnta=\check@bm@number{#1}\relax
    \advance\@tempcnta by1
    \expandafter\xdef\csname#1\endcsname{\the\@tempcnta}}
\endinput
%%
%% End of file `hpdftex.def'.
