%%
%% This is file `htex4ht.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% hyperref.dtx  (with options: `tex4ht')
%% 
%% File: hyperref.dtx Copyright (C) 1995, 1996, 1997, 1998 Sebastian Rahtz
\def\@Form[#1]{%
 \setkeys{Form}{#1}%
 \HCode{<form action="\Form@action" method="\Form@method">}%
}
\def\@endForm{\HCode{</form>}}
\def\@Gauge[#1]#2#3#4{% parameters, label, minimum, maximum
  \typeout{Sorry, TeX4ht does not support gauges}%
}
\def\@TextField[#1]#2{% parameters, label
 \let\reserved@a\@empty
 \def\Fld@name{#2}%
 \def\Fld@default{}%
 \bgroup
 \Field@toks={ }%
 \setkeys{Field}{#1}%
 \HCode{<label for="\Fld@name">#2</label>}%
 \ifFld@password
   \@@PasswordField
 \else
   \@@TextField
 \fi
 \egroup
}
\def\@@PasswordField{%
  \HCode{<input type="password"
   id="\Fld@name"
   name="\Fld@name"
  \ifFld@hidden type="hidden"\fi
   value="\Fld@default" \the\Field@toks>}%
}

\def\@@TextField{%
 \ifFld@multiline
  \HCode{<textarea
  \ifFld@readonly readonly \fi
   id="\Fld@name"
   name="\Fld@name"
  \ifFld@hidden type="hidden"\fi
   \the\Field@toks>}%
   \Fld@default
   \HCode{</textarea>}%
 \else
  \HCode{<input type="textbox"
  \ifFld@readonly readonly \fi
   id="\Fld@name"
   name="\Fld@name"
  \ifFld@hidden type="hidden"\fi
   value="\Fld@default" \the\Field@toks>
  }%
 \fi
}
\def\@ChoiceMenu[#1]#2#3{% parameters, label, choices
 \def\Fld@name{#2}%
 \def\Fld@default{}%
 \let\reserved@a\relax
 \bgroup
 \expandafter\Fld@findlength#3\\
 \Field@toks={ }%
 \setkeys{Field}{#1}%
 #2%
 \ifFld@radio
   \expandafter\@@Radio#3\\%
 \else
   \expandafter\@@Menu#3\\%
 \fi
 \egroup
}
\def\Fld@findlength#1\\{%
  \Fld@menulength=0%
  \@for\@curropt:=#1\do{\advance\Fld@menulength by 1}
}
\def\@@Menu#1\\{%
 \HCode{<select size="\the\Fld@menulength"
 name="\Fld@name"  \the\Field@toks>}%
 \@for\@curropt:=#1\do{
  \expandafter\Fld@checkequals\@curropt==\\%
  \HCode{<option
  \ifx\@curropt\Fld@default selected \fi
    value="\@currValue">\@currDisplay</option>}%
 }%
 \HCode{</select>}%
}
\def\@@Radio#1\\{%
 \@for\@curropt:=#1\do{%
  \expandafter\Fld@checkequals\@curropt==\\%
 \HCode{<input type="radio"
  \ifx\@curropt\Fld@default checked \fi
  name="\Fld@name"
  value="\@currValue" \the\Field@toks>}\@currDisplay}%
}
\def\@PushButton[#1]#2{% parameters, label
 \def\Fld@name{#2}%
 \bgroup
 \Field@toks={ }%
 \setkeys{Field}{#1}%
 \HCode{<input type="button"
   name="\Fld@name"
   value="#2"  \the\Field@toks>}%
  \HCode{</button>}%
 \egroup
}
\def\@Submit[#1]#2{%
 \HCode{<button type="submit">#2</button>}%
}
\def\@Reset[#1]#2{%
 \HCode{<button type="reset">#2</button>}%
}
\def\@CheckBox[#1]#2{% parameters, label
 \let\reserved@a\@empty
 \def\Fld@name{#2}%
 \def\Fld@default{0}%
 \bgroup
 \Field@toks={ }%
 \setkeys{Field}{#1}%
 \HCode{<input type="checkbox"
   \ifFld@checked checked \fi
   \ifFld@disabled disabled \fi
   \ifFld@readonly readonly \fi
   name="\Fld@name"
  \ifFld@hidden type="hidden"\fi
   value="\Fld@default" \the\Field@toks>#2}%
 \egroup
}
\RequirePackage[htex4ht]{tex4ht}
\def\PDF@FinishDoc{}
\def\PDF@SetupDoc{%
 \ifx\@baseurl\@empty\else
  \special{t4ht=<base href="\@baseurl">}%
 \fi
}
\def\hyper@anchor#1{%
   {\let\protect=\string\special{t4ht=<A name=\hyper@quote #1\hyper@quote>}}%
   \hy@activeanchortrue
   \hy@colorlink{\@anchorcolor}\anchor@spot\hy@endcolorlink
   \special{t4ht=</A>}%
   \hy@activeanchorfalse
}
\def\hyper@anchorstart#1{%
 {\hyper@chars\special{t4ht=<A name=\hyper@quote#1\hyper@quote>}}%
  \hy@activeanchortrue
}
\def\hyper@anchorend{%
  \special{t4ht=</A>}%
  \hy@activeanchorfalse
}
\def\@urltype{url}
\def\hyper@linkstart#1#2{%
  \hy@colorlink{\csname @#1color\endcsname}%
  \def\@tempa{#1}\ifx\@tempa\@urltype
    \special{t4ht=<A href=\hyper@quote#2\hyper@quote>}%
  \else
   {\hyper@chars\special{t4ht=<A href=\hyper@quote\##2\hyper@quote>}}%
  \fi
}
\def\hyper@linkend{%
  \special{t4ht=</A>}%
  \hy@endcolorlink
}
\def\hyper@linkfile#1#2#3{%
 \hyper@linkurl{#1}{file:#2\ifx\\#3\\\else\##3\fi}%
}
\def\hyper@linkurl#1#2{%
 \ifhy@raiselinks
  \setbox\@tempboxa=\hbox{#1}%
  \@linkdim\dp\@tempboxa
  \leavevmode\lower\@linkdim\hbox{%
      {\hyper@chars\special{t4ht=<A href=\hyper@quote#2\hyper@quote>}}%
   }%
  \hy@colorlink{\@urlcolor}#1\hy@endcolorlink
  \@linkdim\ht\@tempboxa
  \advance\@linkdim by -6.5\p@
  \raise\@linkdim\hbox{\special{t4ht=</A>}}%
 \else
  {\hyper@chars
   \special{t4ht=<A href=\hyper@quote#2\hyper@quote>}%
   \hy@colorlink{\@urlcolor}#1\hy@endcolorlink
   \special{t4ht=</A>}}%
 \fi
}
\def\hyper@link#1#2#3{%
  \hyper@linkurl{#3}{\##2}%
}
\def\hyper@image#1#2{%
  {\hyper@chars
   \special{t4ht=<img src=\hyper@quote#1\hyper@quote>}}}
\endinput
%%
%% End of file `htex4ht.def'.
