%%
%% This is file `iso88595.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% cyinpenc.dtx  (with options: `ISO88595')
%% 
%% IMPORTANT NOTICE:
%% 
%% For the copyright see the source file.
%% 
%% Any modified versions of this file must be renamed
%% with new filenames distinct from iso88595.def.
%% 
%% For distribution of the original source see the terms
%% for copying and modification in the file cyinpenc.dtx.
%% 
%% This generated file may be distributed as long as the
%% original source files, as listed above, are part of the
%% same distribution. (The sources need not necessarily be
%% in the same archive or directory.)
\ProvidesFile{iso88595.def}
  [1998/09/26 v1.0 Input encoding file]
\DeclareInputText{160}{\nobreakspace}
\DeclareInputText{161}{\CYRYO}
\DeclareInputText{162}{\CYRDJE}
\DeclareInputText{163}{\@tabacckludge'\CYRG}
\DeclareInputText{164}{\CYRIE}
\DeclareInputText{165}{\CYRDZE}
\DeclareInputText{166}{\CYRII}
\DeclareInputText{167}{\CYRYI}
\DeclareInputText{168}{\CYRJE}
\DeclareInputText{169}{\CYRLJE}
\DeclareInputText{170}{\CYRNJE}
\DeclareInputText{171}{\CYRTSHE}
\DeclareInputText{172}{\@tabacckludge'\CYRK}
\DeclareInputText{173}{\-}
\DeclareInputText{174}{\CYRUSHRT}
\DeclareInputText{175}{\CYRDZHE}
\DeclareInputText{176}{\CYRA}
\DeclareInputText{177}{\CYRB}
\DeclareInputText{178}{\CYRV}
\DeclareInputText{179}{\CYRG}
\DeclareInputText{180}{\CYRD}
\DeclareInputText{181}{\CYRE}
\DeclareInputText{182}{\CYRZH}
\DeclareInputText{183}{\CYRZ}
\DeclareInputText{184}{\CYRI}
\DeclareInputText{185}{\CYRISHRT}
\DeclareInputText{186}{\CYRK}
\DeclareInputText{187}{\CYRL}
\DeclareInputText{188}{\CYRM}
\DeclareInputText{189}{\CYRN}
\DeclareInputText{190}{\CYRO}
\DeclareInputText{191}{\CYRP}
\DeclareInputText{192}{\CYRR}
\DeclareInputText{193}{\CYRS}
\DeclareInputText{194}{\CYRT}
\DeclareInputText{195}{\CYRU}
\DeclareInputText{196}{\CYRF}
\DeclareInputText{197}{\CYRH}
\DeclareInputText{198}{\CYRC}
\DeclareInputText{199}{\CYRCH}
\DeclareInputText{200}{\CYRSH}
\DeclareInputText{201}{\CYRSHCH}
\DeclareInputText{202}{\CYRHRDSN}
\DeclareInputText{203}{\CYRERY}
\DeclareInputText{204}{\CYRSFTSN}
\DeclareInputText{205}{\CYREREV}
\DeclareInputText{206}{\CYRYU}
\DeclareInputText{207}{\CYRYA}
\DeclareInputText{208}{\cyra}
\DeclareInputText{209}{\cyrb}
\DeclareInputText{210}{\cyrv}
\DeclareInputText{211}{\cyrg}
\DeclareInputText{212}{\cyrd}
\DeclareInputText{213}{\cyre}
\DeclareInputText{214}{\cyrzh}
\DeclareInputText{215}{\cyrz}
\DeclareInputText{216}{\cyri}
\DeclareInputText{217}{\cyrishrt}
\DeclareInputText{218}{\cyrk}
\DeclareInputText{219}{\cyrl}
\DeclareInputText{220}{\cyrm}
\DeclareInputText{221}{\cyrn}
\DeclareInputText{222}{\cyro}
\DeclareInputText{223}{\cyrp}
\DeclareInputText{224}{\cyrr}
\DeclareInputText{225}{\cyrs}
\DeclareInputText{226}{\cyrt}
\DeclareInputText{227}{\cyru}
\DeclareInputText{228}{\cyrf}
\DeclareInputText{229}{\cyrh}
\DeclareInputText{230}{\cyrc}
\DeclareInputText{231}{\cyrch}
\DeclareInputText{232}{\cyrsh}
\DeclareInputText{233}{\cyrshch}
\DeclareInputText{234}{\cyrhrdsn}
\DeclareInputText{235}{\cyrery}
\DeclareInputText{236}{\cyrsftsn}
\DeclareInputText{237}{\cyrerev}
\DeclareInputText{238}{\cyryu}
\DeclareInputText{239}{\cyrya}
\DeclareInputText{240}{\numero}
\DeclareInputText{241}{\cyryo}
\DeclareInputText{242}{\cyrdje}
\DeclareInputText{243}{\@tabacckludge'\cyrg}
\DeclareInputText{244}{\cyrie}
\DeclareInputText{245}{\cyrdze}
\DeclareInputText{246}{\cyrii}
\DeclareInputText{247}{\cyryi}
\DeclareInputText{248}{\cyrje}
\DeclareInputText{249}{\cyrlje}
\DeclareInputText{250}{\cyrnje}
\DeclareInputText{251}{\cyrtshe}
\DeclareInputText{252}{\@tabacckludge'\cyrk}
\DeclareInputText{253}{\S}
\DeclareInputText{254}{\cyrushrt}
\DeclareInputText{255}{\cyrdzhe}
\endinput
%%
%% End of file `iso88595.def'.
