%%
%% This is file `cpmnk.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% cyinpenc.dtx  (with options: `MNK')
%% 
%% IMPORTANT NOTICE:
%% 
%% For the copyright see the source file.
%% 
%% Any modified versions of this file must be renamed
%% with new filenames distinct from cpmnk.def.
%% 
%% For distribution of the original source see the terms
%% for copying and modification in the file cyinpenc.dtx.
%% 
%% This generated file may be distributed as long as the
%% original source files, as listed above, are part of the
%% same distribution. (The sources need not necessarily be
%% in the same archive or directory.)
\ProvidesFile{cpmnk.def}
  [1998/09/26 v1.0 Input encoding file]
\DeclareInputText{128}{\CYRA}
\DeclareInputText{129}{\CYRB}
\DeclareInputText{130}{\CYRV}
\DeclareInputText{131}{\CYRG}
\DeclareInputText{132}{\CYRD}
\DeclareInputText{133}{\CYRE}
\DeclareInputText{134}{\CYRYO}
\DeclareInputText{135}{\CYRZH}
\DeclareInputText{136}{\CYRZ}
\DeclareInputText{137}{\CYRI}
\DeclareInputText{138}{\CYRISHRT}
\DeclareInputText{139}{\CYRK}
\DeclareInputText{140}{\CYRL}
\DeclareInputText{141}{\CYRM}
\DeclareInputText{142}{\CYRN}
\DeclareInputText{143}{\CYRO}
\DeclareInputText{144}{\CYROTLD}
\DeclareInputText{145}{\CYRP}
\DeclareInputText{146}{\CYRR}
\DeclareInputText{147}{\CYRS}
\DeclareInputText{148}{\CYRT}
\DeclareInputText{149}{\CYRU}
\DeclareInputText{150}{\CYRY}
\DeclareInputText{151}{\CYRF}
\DeclareInputText{152}{\CYRH}
\DeclareInputText{153}{\CYRC}
\DeclareInputText{154}{\CYRCH}
\DeclareInputText{155}{\CYRSH}
\DeclareInputText{156}{\CYRSHCH}
\DeclareInputText{157}{\CYRHRDSN}
\DeclareInputText{158}{\CYRERY}
\DeclareInputText{159}{\CYRSFTSN}
\DeclareInputText{160}{\CYREREV}
\DeclareInputText{161}{\CYRYU}
\DeclareInputText{162}{\CYRYA}
\DeclareInputText{163}{\cyra}
\DeclareInputText{164}{\cyrb}
\DeclareInputText{165}{\cyrv}
\DeclareInputText{166}{\cyrg}
\DeclareInputText{167}{\cyrd}
\DeclareInputText{168}{\cyre}
\DeclareInputText{169}{\cyryo}
\DeclareInputText{170}{\cyrzh}
\DeclareInputText{173}{\cyrz}
\DeclareInputText{224}{\cyri}
\DeclareInputText{225}{\cyrishrt}
\DeclareInputText{226}{\cyrk}
\DeclareInputText{227}{\cyrl}
\DeclareInputText{228}{\cyrm}
\DeclareInputText{229}{\cyrn}
\DeclareInputText{230}{\cyro}
\DeclareInputText{231}{\cyrotld}
\DeclareInputText{232}{\cyrp}
\DeclareInputText{233}{\cyrr}
\DeclareInputText{234}{\cyrs}
\DeclareInputText{235}{\cyrt}
\DeclareInputText{236}{\cyru}
\DeclareInputText{237}{\cyry}
\DeclareInputText{238}{\cyrf}
\DeclareInputText{239}{\cyrh}
\DeclareInputText{240}{\cyrc}
\DeclareInputText{241}{\cyrch}
\DeclareInputText{242}{\cyrsh}
\DeclareInputText{243}{\cyrshch}
\DeclareInputText{244}{\cyrhrdsn}
\DeclareInputText{245}{\cyrery}
\DeclareInputText{248}{\cyrsftsn}
\DeclareInputText{252}{\cyrerev}
\DeclareInputText{253}{\cyryu}
\DeclareInputText{254}{\cyrya}
\endinput
%%
%% End of file `cpmnk.def'.
