%%
%% This is file `LGRenc.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% greek.fdd  (with options: `LGRenc')
%% 
%% This is a generated file.
%% 
%% Copyright 1996 Johannes L. Braams and any individual authors
%% listed elsewhere in this file.  All rights reserved.
%% 
%% For further copyright information, and conditions for modification
%% and distribution, see any other copyright notices in this file.
%% 
%% This file is part of the Babel system, release 3.6.
%% ---------------------------------------------------
%%   This system is distributed in the hope that it will be useful,
%%   but WITHOUT ANY WARRANTY; without even the implied warranty of
%%   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
%% 
%%   For error reports concerning UNCHANGED versions of this file no
%%   more than one year old, see bugs.txt.
%% 
%%   Please do not request updates from me directly.  Primary
%%   distribution is through the CTAN archives.
%% 
%% 
%% IMPORTANT COPYRIGHT NOTICE:
%% 
%% You are NOT ALLOWED to distribute this file alone.
%% 
%% You are allowed to distribute this file under the condition that it
%% is distributed together with all the files listed in manifest.txt.
%% 
%% If you receive only some of these files from someone, complain!
%% 
%% 
%% Permission is granted to customize the declarations in this file to
%% serve the needs of your installation, provided that you comply with
%% the conditions in the file legal.txt.
%% 
%% However, NO PERMISSION is granted to distribute a modified version
%% of this file under its original name.
%% 
%% 
%% MODIFICATION ADVICE:
%% 
%% If you want to customize this file, it is best to make a copy of
%% the source file(s) from which it was produced.  Use a different
%% name for your copy(ies) and modify the copy(ies); this will ensure
%% that your modifications do not get overwritten when you install a
%% new release of the standard system.
%% 
%% You can then easily distribute your modifications by distributing
%% the modified and renamed copy of the source file, together with a
%% suitable .ins file, taking care to observe the conditions in
%% legal.txt; this will ensure that other users can safely use
%% your modifications.
%% 
%% The names of the source files used are shown above.
%% 
%% 
%% 
\ProvidesFile{LGRenc.def}
        [1997/01/09 v1.0c
  Greek Encoding]
\DeclareFontEncoding{LGR}{}{}
\DeclareFontSubstitution{LGR}{cmr}{m}{n}
\DeclareErrorFont{LGR}{cmr}{m}{n}{10}
\let\ltxTeX\TeX
\DeclareTextCommandDefault{\TeX}{\textlatin{\ltxTeX}}
\let\ltxLaTeX\LaTeX
\DeclareTextCommandDefault{\LaTeX}{\textlatin{\ltxLaTeX}}
\ProvideTextCommand{\copyright}{LGR}{%
  \textcircled{\textlatin{c}}}
\ProvideTextCommand{\textregistered}{LGR}{%
  \textcircled{\latintext\textsc r}}
\ProvideTextCommand{\textrademark}{LGR}{%
  \textsuperscript{\latintext TM}}
\ProvideTextCommand{\SS}{LGR}{%
  \textlatin{SS}}
\endinput
%%
%% End of file `LGRenc.def'.
