%%
%% This is file `mazovia.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% strony.dtx  (with options: `mazovia')
%% 
%% IMPORTANT NOTICE:
%% 
%% For the copyright see the source file.
%% 
%% Any modified versions of this file must be renamed
%% with new filenames distinct from mazovia.def.
%% 
%% For distribution of the original source see the terms
%% for copying and modification in the file strony.dtx.
%% 
%% This generated file may be distributed as long as the
%% original source files, as listed above, are part of the
%% same distribution. (The sources need not necessarily be
%% in the same archive or directory.)
\ProvidesFile{mazovia.def}
\DeclareInputText{143}{\k A}
\DeclareInputText{149}{\@tabacckludge'C}
\DeclareInputText{144}{\k E}
\DeclareInputText{156}{\L}
\DeclareInputText{165}{\@tabacckludge'N}
\DeclareInputText{163}{\@tabacckludge'O}
\DeclareInputText{152}{\@tabacckludge'S}
\DeclareInputText{160}{\@tabacckludge'Z}
\DeclareInputText{161}{\.Z}
\DeclareInputText{134}{\k a}
\DeclareInputText{141}{\@tabacckludge'c}
\DeclareInputText{145}{\k e}
\DeclareInputText{146}{\l}
\DeclareInputText{164}{\@tabacckludge'n}
\DeclareInputText{162}{\@tabacckludge'o}
\DeclareInputText{158}{\@tabacckludge's}
\DeclareInputText{166}{\@tabacckludge'z}
\DeclareInputText{167}{\.z}
\endinput
%%
%% End of file `mazovia.def'.
