%%
%% This is file `lwnenc.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% cyrillic.fdd  (with options: `LWNenc')
%% 
%% This is a generated file.
%% 
%% Copyright 1995, 1996 CyrTUG and any individual
%% authors listed elsewhere in this file.
%% 
%% 
%% This is a generated file.
%% 
%% Copyright 1996 Johannes L. Braams and any individual authors
%% listed elsewhere in this file.  All rights reserved.
%% 
%% For further copyright information, and conditions for modification
%% and distribution, see any other copyright notices in this file.
%% 
%% This file is part of the Babel system, release 3.6.
%% ---------------------------------------------------
%%   This system is distributed in the hope that it will be useful,
%%   but WITHOUT ANY WARRANTY; without even the implied warranty of
%%   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
%% 
%%   For error reports concerning UNCHANGED versions of this file no
%%   more than one year old, see bugs.txt.
%% 
%%   Please do not request updates from me directly.  Primary
%%   distribution is through the CTAN archives.
%% 
%% 
%% IMPORTANT COPYRIGHT NOTICE:
%% 
%% You are NOT ALLOWED to distribute this file alone.
%% 
%% You are allowed to distribute this file under the condition that it
%% is distributed together with all the files listed in manifest.txt.
%% 
%% If you receive only some of these files from someone, complain!
%% 
%% 
%% Permission is granted to customize the declarations in this file to
%% serve the needs of your installation, provided that you comply with
%% the conditions in the file legal.txt.
%% 
%% However, NO PERMISSION is granted to distribute a modified version
%% of this file under its original name.
%% 
%% 
%% MODIFICATION ADVICE:
%% 
%% If you want to customize this file, it is best to make a copy of
%% the source file(s) from which it was produced.  Use a different
%% name for your copy(ies) and modify the copy(ies); this will ensure
%% that your modifications do not get overwritten when you install a
%% new release of the standard system.
%% 
%% You can then easily distribute your modifications by distributing
%% the modified and renamed copy of the source file, together with a
%% suitable .ins file, taking care to observe the conditions in
%% legal.txt; this will ensure that other users can safely use
%% your modifications.
%% 
%% The names of the source files used are shown above.
%% 
%% 
%% 
\ProvidesFile{lwnenc.def}
        [1998/09/10 v3.0c
         Washington Cyrillic font encoding]
\DeclareFontEncoding{LWN}{}{}
\DeclareFontSubstitution{LWN}{cmr}{m}{n}
\DeclareErrorFont{LWN}{cmr}{m}{n}{10}
\DeclareSymbolFont{LWNletters}{LWN}\rmdefault\mddefault\updefault
\SetSymbolFont{LWNletters}{bold}{LWN}\rmdefault\bfdefault\updefault
\ProvideTextCommand{\copyright}{LWN}
  {\textcircled{\textlatin{c}}}
\ProvideTextCommand{\textregistered}{LWN}
  {\textcircled{\latintext\textsc r}}
\ProvideTextCommand{\textrademark}{LWN}
  {\textsuperscript{\latintext TM}}
\ProvideTextCommand{\SS}{LWN}
  {\textlatin{SS}}
\def\CYRA{A}
\def\CYRB{B}
\def\CYRV{V}
\def\CYRG{G}
\def\CYRD{D}
\def\CYRE{E}
\def\CYRZH{ZH}
\def\CYRZ{Z}
\def\CYRI{I}
\def\CYRISHRT{I0}
\def\CYRK{K}
\def\CYRL{L}
\def\CYRM{M}
\def\CYRN{N}
\def\CYRO{O}
\def\CYRP{P}
\def\CYRR{R}
\def\CYRS{S}
\def\CYRT{T}
\def\CYRU{U}
\def\CYRF{F}
\def\CYRH{H}
\def\CYRC{C}
\def\CYRCH{Q}
\def\CYRSH{X}
\def\CYRSHCH{W}
\def\CYRHRDSN{P2}
\def\CYRERY{Y}
\def\CYRSFTSN{P1}
\def\CYREREV{E1}
\def\CYRYU{YU}
\def\CYRYA{YA}
\def\CYRYO{E0}
\def\cyra{a}
\def\cyrb{b}
\def\cyrv{v}
\def\cyrg{g}
\def\cyrd{d}
\def\cyre{e}
\def\cyrzh{zh}
\def\cyrz{z}
\def\cyri{i}
\def\cyrishrt{i0}
\def\cyrk{k}
\def\cyrl{l}
\def\cyrm{m}
\def\cyrn{n}
\def\cyro{o}
\def\cyrp{p}
\def\cyrr{r}
\def\cyrs{s}
\def\cyrt{t}
\def\cyru{u}
\def\cyrf{f}
\def\cyrh{h}
\def\cyrc{c}
\def\cyrch{q}
\def\cyrsh{x}
\def\cyrshch{w}
\def\cyrhrdsn{p2}
\def\cyrery{y}
\def\cyrsftsn{p1}
\def\cyrerev{e1}
\def\cyryu{yu}
\def\cyrya{ya}
\def\cyryo{e0}
\DeclareTextSymbol\textnumero{LWN}{125}
\DeclareMathSymbol\mathnumero{\mathalpha}{LWNletters}{125}
\DeclareRobustCommand\numero{\ifmmode\mathnumero\else\textnumero\fi}
\DeclareTextSymbol\guillemotleft{LWN}{60}
\DeclareTextSymbol\guillemotright{LWN}{62}
\endinput
%%
%% End of file `lwnenc.def'.
