%%
%% This is file `hdviwind.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% hyperref.dtx  (with options: `pdfmarkbase,dviwindo')
%% 
%% File: hyperref.dtx Copyright (C) 1995, 1996, 1997, 1998 Sebastian Rahtz

\providecommand\wwwbrowser{c:\string\netscape\string\netscape}
\def\hyper@anchor#1{%
   {\let\protect=\string\special{mark:  #1}}%
   \hy@activeanchortrue
   \hy@colorlink{\@anchorcolor}\anchor@spot\hy@endcolorlink
   \hy@activeanchorfalse
}
\def\hyper@anchorstart#1{%
  \special{mark: #1}%
  \hy@activeanchortrue
}
\def\hyper@anchorend{%
  \hy@activeanchorfalse
}
\def\hyper@linkstart#1#2{%
  \hy@colorlink{\csname @#1color\endcsname}%
  \special{button:  10000000 \number\baselineskip \space
      #2}%
}
\def\hyper@linkend{%
  \hy@endcolorlink
}
\def\hyper@link#1#2#3{%
 \ifhy@raiselinks
  \setbox\@tempboxa=\hbox{#3}%
  \@linkdim\dp\@tempboxa
  \leavevmode\lower\@linkdim\hbox{%
  \special{button:  \number\wd\@tempboxa\space \number\ht\@tempboxa\space
      #2}%
  \hy@colorlink{\csname @#1color\endcsname}#3\hy@endcolorlink}%
  \@linkdim\ht\@tempboxa
  \advance\@linkdim by -6.5\p@
  \raise\@linkdim\hbox{}%
 \else
  \setbox\@tempboxa=\hbox{#3}%
  \special{button:  \number\wd\@tempboxa\space \number\ht\@tempboxa\space
      #2}%
  \hy@colorlink{\csname @#1color\endcsname}#3\hy@endcolorlink
 \fi
}
\def\hyper@linkurl#1#2{%
\bgroup\hyper@chars
 \ifhy@raiselinks
  \setbox\@tempboxa=\hbox{#1}%
  \@linkdim\dp\@tempboxa
  \leavevmode\lower\@linkdim\hbox{%
  \special{button:  \number\wd\@tempboxa\space \number\ht\@tempboxa\space
        launch: \wwwbrowser\space
       #2}%
  \hy@colorlink{\@urlcolor}#1\hy@endcolorlink}%
  \@linkdim\ht\@tempboxa
  \advance\@linkdim by -6.5\p@
  \raise\@linkdim\hbox{}%
 \else
  \setbox\@tempboxa=\hbox{#1}%
  \special{button:  \number\wd\@tempboxa\space \number\ht\@tempboxa\space
        launch: \wwwbrowser\space
      #2}%
  \hy@colorlink{\@urlcolor}#1\hy@endcolorlink
 \fi
\egroup
}
\def\hyper@linkfile#1#2#3{%
\bgroup\hyper@chars
 \ifhy@raiselinks
  \setbox\@tempboxa=\hbox{#1}%
  \@linkdim\dp\@tempboxa
  \leavevmode\lower\@linkdim\hbox{%
  \special{button:  \number\wd\@tempboxa\space \number\ht\@tempboxa\space
      #3,\space file: #2}%
  \hy@colorlink{\@filecolor}#1\hy@endcolorlink}%
  \@linkdim\ht\@tempboxa
  \advance\@linkdim by -6.5\p@
  \raise\@linkdim\hbox{}%
 \else
  \setbox\@tempboxa=\hbox{#1}%
  \special{button:  \number\wd\@tempboxa\space \number\ht\@tempboxa\space
      #3,\space file: #2}%
  \hy@colorlink{\@filecolor}#1\hy@endcolorlink
 \fi
\egroup
}
\def\@pdfproducer{dviwindo + Distiller}
\def\PDF@FinishDoc{
 \special{PDF: Keywords \@pdfkeywords}%
 \special{PDF: Title \@pdftitle}%
 \special{PDF: Creator \@pdfcreator}%
 \special{PDF: Author \@pdfauthor}%
 \special{PDF: Producer \@pdfproducer}%
 \special{PDF: Subject \@pdfsubject}%
}
\def\PDF@SetupDoc{
 \ifx\@baseurl\@empty\else
  \special{PDF: Base \@baseurl}%
 \fi
 \ifx\@pdfpagescrop\@empty\else
  \special{PDF: BBox \@pdfpagescrop}%
 \fi
 \pdfmark{pdfmark=/DOCVIEW,
   Page=\@pdfstartpage,
   View=\@pdfstartview,
   PageMode=\@pdfpagemode
   }
 \ifx\@pdfpagescrop\@empty\else
   \pdfmark{pdfmark=/PAGES,CropBox=\@pdfpagescrop}%
 \fi
 \pdfmark{pdfmark=/PUT,Raw={
 \string{Catalog\string} <<
   /ViewerPreferences <<
  \ifhy@toolbar\else /HideToolbar true \fi
  \ifhy@menubar\else /HideMenubar true \fi
  \ifhy@windowui\else /HideWindowUI true \fi
  \ifhy@fitwindow /FitWindow true \fi
  \ifhy@centerwindow /CenterWindow true \fi
   >>
  \ifx\pdf@pagelayout\@empty\else/PageLayout /\pdf@pagelayout\space\fi
  >>}}%
}
\def\pdfmark{\@ifnextchar[{\pdfmark@}{\pdfmark@[]}}
\def\pdfmark@[#1]#2{%
    \edef\@processme{\noexpand\pdf@toks={ \the\pdf@defaulttoks}}%
    \@processme
    \let\pdf@type\relax
    \setkeys{PDF}{#2}%
    \ifx\pdf@type\relax
       \hyper@warn{no pdfmark type specified in #2!!}%
       \ifx\\#1\\\relax\else\pdf@rect{#1}\fi
    \else
       \ifx\\#1\\\relax
  \literalps@out{[\the\pdf@toks\space \pdf@type\space pdfmark}%
       \else
         \hy@colorlink{\@ifundefined{@\pdf@linktype color}%
                      {\@linkcolor}%
                      {\csname @\pdf@linktype color\endcsname}}%
         \pdf@rect{#1}%
  \literalps@out{[\the\pdf@toks\space \pdf@type\space pdfmark}%
         \hy@endcolorlink
       \fi
    \fi
}
\newsavebox{\pdf@box}
\def\pdf@rect#1{%
   \leavevmode
   \sbox\pdf@box{#1}%
   \dimen@\ht\pdf@box
   \leavevmode\lower\dp\pdf@box\hbox{\PSHyperRectStart}%
   \ifhy@breaklinks\unhbox\else\box\fi\pdf@box
   \raise\dimen@\hbox{\PSHyperRectEnd}%
   \pdf@addtoks{[\pdf@bbox]}{Rect}%
}
\newtoks\pdf@toks
\newtoks\pdf@defaulttoks
\pdf@defaulttoks={ }%
\def\pdf@addtoks#1#2{%
   \edef\@processme{\pdf@toks{\the\pdf@toks\space /#2 #1}}%
   \@processme
}
\def\pdf@addtoksx#1{%
   \edef\@processme{\pdf@toks{\the\pdf@toks\space #1}}%
   \@processme
}
\def\PDFdefaults#1{%
 \pdf@defaulttoks={#1}%
}
\define@key{PDF}{pdfmark}{\def\pdf@type{#1}}
\define@key{PDF}{linktype}{\def\pdf@linktype{#1}}
\def\pdf@linktype{link}
\define@key{PDF}{Raw}{\pdf@addtoksx{#1}}
\define@key{PDF}{Action}{\pdf@addtoks{#1}{Action}}
\define@key{PDF}{Border}{\pdf@addtoks{[#1]}{Border}}
\define@key{PDF}{Color}{\pdf@addtoks{[#1]}{Color}}
\define@key{PDF}{Contents}{\pdf@addtoks{(#1)}{Contents}}
\define@key{PDF}{Count}{\pdf@addtoks{#1}{Count}}
\define@key{PDF}{CropBox}{\pdf@addtoks{[#1]}{CropBox}}
\define@key{PDF}{DOSFile}{\pdf@addtoks{(#1)}{DOSFile}}
\define@key{PDF}{DataSource}{\pdf@addtoks{(#1)}{DataSource}}
\define@key{PDF}{Dest}{\ifx\\#1\\\else\pdf@addtoks{/#1}{Dest}\fi}
\define@key{PDF}{DestAnchor}{\ifx\\#1\\\else
      \pdf@addtoks{/#1 }{Dest}\fi}
\define@key{PDF}{Dir}{\pdf@addtoks{(#1)}{Dir}}
\define@key{PDF}{File}{\pdf@addtoks{(#1)}{File}}
\define@key{PDF}{Flags}{\pdf@addtoks{#1}{Flags}}
\define@key{PDF}{AcroHighlight}{\pdf@addtoks{#1}{H}}
\define@key{PDF}{ID}{\pdf@addtoks{[#1]}{ID}}
\define@key{PDF}{MacFile}{\pdf@addtoks{(#1)}{MacFile}}
\define@key{PDF}{ModDate}{\pdf@addtoks{(#1)}{ModDate}}
\define@key{PDF}{Op}{\pdf@addtoks{(#1)}{Op}}
\define@key{PDF}{Open}{\pdf@addtoks{#1}{Open}}
\define@key{PDF}{Page}{\pdf@addtoks{#1}{Page}}
\define@key{PDF}{PageMode}{\pdf@addtoks{#1}{PageMode}}
\define@key{PDF}{Params}{\pdf@addtoks{(#1)}{Params}}
\define@key{PDF}{Rect}{\pdf@addtoks{[#1]}{Rect}}
\define@key{PDF}{SrcPg}{\pdf@addtoks{#1}{SrcPg}}
\define@key{PDF}{Subtype}{\pdf@addtoks{#1}{Subtype}}
\define@key{PDF}{Title}{\pdf@addtoks{(#1)}{Title}}
\define@key{PDF}{Unix}{\pdf@addtoks{(#1)}{Unix}}
\define@key{PDF}{UnixFile}{\pdf@addtoks{(#1)}{UnixFile}}
\define@key{PDF}{View}{\pdf@addtoks{[#1]}{View}}
\define@key{PDF}{WinFile}{\pdf@addtoks{(#1)}{WinFile}}
\define@key{PDF}{Author}{\pdf@addtoks{(#1)}{Author}}
\define@key{PDF}{CreationDate}{\pdf@addtoks{(#1)}{CreationDate}}
\define@key{PDF}{Creator}{\pdf@addtoks{(#1)}{Creator}}
\define@key{PDF}{Producer}{\pdf@addtoks{(#1)}{Producer}}
\define@key{PDF}{Subject}{\pdf@addtoks{(#1)}{Subject}}
\define@key{PDF}{Keywords}{\pdf@addtoks{(#1)}{Keywords}}
\define@key{PDF}{ModDate}{\pdf@addtoks{(#1)}{ModDate}}
\define@key{PDF}{Base}{\pdf@addtoks{(#1)}{Base}}
\define@key{PDF}{URI}{\pdf@addtoks{#1}{URI}}
\endinput
%%
%% End of file `hdviwind.def'.
