%%
%% This is file `cp866mav.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% cyinpenc.dtx  (with options: `cp866,MAV')
%% 
%% IMPORTANT NOTICE:
%% 
%% For the copyright see the source file.
%% 
%% Any modified versions of this file must be renamed
%% with new filenames distinct from cp866mav.def.
%% 
%% For distribution of the original source see the terms
%% for copying and modification in the file cyinpenc.dtx.
%% 
%% This generated file may be distributed as long as the
%% original source files, as listed above, are part of the
%% same distribution. (The sources need not necessarily be
%% in the same archive or directory.)
\ProvidesFile{cp866mav.def}
  [1998/09/26 v1.0 Input encoding file]
\ProvideTextCommandDefault{\textblacksquare}
  {\vrule \@width .3em \@height .4em \@depth -.1em\relax}
\ProvideTextCommandDefault{\textdegree}{\ensuremath{{^\circ}}}
\providecommand{\mathtwosuperior}{{^2}}
\providecommand{\mathnsuperior}{{^n}}
\DeclareInputText{128}{\CYRA}
\DeclareInputText{129}{\CYRB}
\DeclareInputText{130}{\CYRV}
\DeclareInputText{131}{\CYRG}
\DeclareInputText{132}{\CYRD}
\DeclareInputText{133}{\CYRE}
\DeclareInputText{134}{\CYRZH}
\DeclareInputText{135}{\CYRZ}
\DeclareInputText{136}{\CYRI}
\DeclareInputText{137}{\CYRISHRT}
\DeclareInputText{138}{\CYRK}
\DeclareInputText{139}{\CYRL}
\DeclareInputText{140}{\CYRM}
\DeclareInputText{141}{\CYRN}
\DeclareInputText{142}{\CYRO}
\DeclareInputText{143}{\CYRP}
\DeclareInputText{144}{\CYRR}
\DeclareInputText{145}{\CYRS}
\DeclareInputText{146}{\CYRT}
\DeclareInputText{147}{\CYRU}
\DeclareInputText{148}{\CYRF}
\DeclareInputText{149}{\CYRH}
\DeclareInputText{150}{\CYRC}
\DeclareInputText{151}{\CYRCH}
\DeclareInputText{152}{\CYRSH}
\DeclareInputText{153}{\CYRSHCH}
\DeclareInputText{154}{\CYRHRDSN}
\DeclareInputText{155}{\CYRERY}
\DeclareInputText{156}{\CYRSFTSN}
\DeclareInputText{157}{\CYREREV}
\DeclareInputText{158}{\CYRYU}
\DeclareInputText{159}{\CYRYA}
\DeclareInputText{160}{\cyra}
\DeclareInputText{161}{\cyrb}
\DeclareInputText{162}{\cyrv}
\DeclareInputText{163}{\cyrg}
\DeclareInputText{164}{\cyrd}
\DeclareInputText{165}{\cyre}
\DeclareInputText{166}{\cyrzh}
\DeclareInputText{167}{\cyrz}
\DeclareInputText{168}{\cyri}
\DeclareInputText{169}{\cyrishrt}
\DeclareInputText{170}{\cyrk}
\DeclareInputText{171}{\cyrl}
\DeclareInputText{172}{\cyrm}
\DeclareInputText{173}{\cyrn}
\DeclareInputText{174}{\cyro}
\DeclareInputText{175}{\cyrp}
\DeclareInputText{224}{\cyrr}
\DeclareInputText{225}{\cyrs}
\DeclareInputText{226}{\cyrt}
\DeclareInputText{227}{\cyru}
\DeclareInputText{228}{\cyrf}
\DeclareInputText{229}{\cyrh}
\DeclareInputText{230}{\cyrc}
\DeclareInputText{231}{\cyrch}
\DeclareInputText{232}{\cyrsh}
\DeclareInputText{233}{\cyrshch}
\DeclareInputText{234}{\cyrhrdsn}
\DeclareInputText{235}{\cyrery}
\DeclareInputText{236}{\cyrsftsn}
\DeclareInputText{237}{\cyrerev}
\DeclareInputText{238}{\cyryu}
\DeclareInputText{239}{\cyrya}
\DeclareInputText{240}{\CYRYO}
\DeclareInputText{241}{\cyryo}
\DeclareInputMath{242}{\geq}
\DeclareInputMath{243}{\leq}
\DeclareInputMath{246}{\div}
\DeclareInputMath{247}{\sim}
\DeclareInputText{248}{\textdegree}
\DeclareInputText{249}{\textbullet}
\DeclareInputText{250}{\textperiodcentered}
\DeclareInputMath{251}{\surd}
\DeclareInputMath{252}{\mathnsuperior}
\DeclareInputMath{253}{\mathtwosuperior}
\DeclareInputText{254}{\textblacksquare}
\DeclareInputText{255}{\nobreakspace}
\endinput
%%
%% End of file `cp866mav.def'.
