% latin1jk.def
%
% (c) Copyright 1995, 1996 J"org Knappen.
% Licence GNU licence Version 2
% see after \endinput for further information
%
\NeedsTeXFormat{LaTeX2e}[1995/12/01]
\ProvidesFile{latin1jk.def}[1996/02/11 latin-1 input encoding file 1.1 (jk)]
%%% \RequirePackage{textcomp}    % text companion symbols (tc fonts)
\DeclareInputText{"0A0}{\nobreakspace}
\DeclareInputText{"0B0}{\textdegree}
\DeclareInputText{"0A1}{\textexclamdown}
\DeclareInputText{"0B1}{\textplusminus}
\DeclareInputText{"0A2}{\textcent}
\DeclareInputText{"0B2}{\texttwosuperior}
\DeclareInputText{"0A3}{\pounds}
\DeclareInputText{"0B3}{\textthreesuperior}
\DeclareInputText{"0A4}{\textcurrency}
\DeclareInputText{"0B4}{\@tabacckludge'{}}
\DeclareInputText{"0A5}{\textyen}
\DeclareInputText{"0B5}{\textmu}
\DeclareInputText{"0A6}{\textbrokenbar}
\DeclareInputText{"0B6}{\P}
\DeclareInputText{"0A7}{\S}
\DeclareInputText{"0B7}{\textperiodcentered}
\DeclareInputText{"0A8}{\"{}}
\DeclareInputText{"0B8}{\c{\ }}
\DeclareInputText{"0A9}{\copyright}
\DeclareInputText{"0B9}{\textonesuperior}
\DeclareInputText{"0AA}{\textordfeminine}
\DeclareInputText{"0BA}{\textordmasculine}
\DeclareInputText{"0AB}{\guillemotleft}
\DeclareInputText{"0BB}{\guillemotright}
\DeclareInputText{"0AC}{\textlogicalnot}
\DeclareInputText{"0BC}{\textonequarter}
\DeclareInputText{"0AD}{\@dischyph}
\DeclareInputText{"0BD}{\textonehalf}
\DeclareInputText{"0AE}{\textregistered}
\DeclareInputText{"0BE}{\textthreequarters}
\DeclareInputText{"0AF}{\@tabacckludge={}}
\DeclareInputText{"0BF}{\textquestiondown}
\DeclareInputText{"0C0}{\@tabacckludge`A}
\DeclareInputText{"0D0}{\DH}
\DeclareInputText{"0C1}{\@tabacckludge'A}
\DeclareInputText{"0D1}{\~N}
\DeclareInputText{"0C2}{\^A}
\DeclareInputText{"0D2}{\@tabacckludge`O}
\DeclareInputText{"0C3}{\~A}
\DeclareInputText{"0D3}{\@tabacckludge'O}
\DeclareInputText{"0C4}{\"A}
\DeclareInputText{"0D4}{\^O}
\DeclareInputText{"0C5}{\AA}
\DeclareInputText{"0D5}{\~O}
\DeclareInputText{"0C6}{\AE}
\DeclareInputText{"0D6}{\"O}
\DeclareInputText{"0C7}{\c C}
\DeclareInputText{"0D7}{\textmultiply}
\DeclareInputText{"0C8}{\@tabacckludge`E}
\DeclareInputText{"0D8}{\O}
\DeclareInputText{"0C9}{\@tabacckludge'E}
\DeclareInputText{"0D9}{\@tabacckludge`U}
\DeclareInputText{"0CA}{\^E}
\DeclareInputText{"0DA}{\@tabacckludge'U}
\DeclareInputText{"0CB}{\"E}
\DeclareInputText{"0DB}{\^U}
\DeclareInputText{"0CC}{\@tabacckludge`I}
\DeclareInputText{"0DC}{\"U}
\DeclareInputText{"0CD}{\@tabacckludge'I}
\DeclareInputText{"0DD}{\@tabacckludge'Y}
\DeclareInputText{"0CE}{\^I}
\DeclareInputText{"0DE}{\TH}
\DeclareInputText{"0CF}{\"I}
\DeclareInputText{"0DF}{\ss}
\DeclareInputText{"0E0}{\@tabacckludge`a}
\DeclareInputText{"0F0}{\dh}
\DeclareInputText{"0E1}{\@tabacckludge'a}
\DeclareInputText{"0F1}{\~n}
\DeclareInputText{"0E2}{\^a}
\DeclareInputText{"0F2}{\@tabacckludge`o}
\DeclareInputText{"0E3}{\~a}
\DeclareInputText{"0F3}{\@tabacckludge'o}
\DeclareInputText{"0E4}{\"a}
\DeclareInputText{"0F4}{\^o}
\DeclareInputText{"0E5}{\aa}
\DeclareInputText{"0F5}{\~o}
\DeclareInputText{"0E6}{\ae}
\DeclareInputText{"0F6}{\"o}
\DeclareInputText{"0E7}{\c c}
\DeclareInputText{"0F7}{\textdivide}
\DeclareInputText{"0E8}{\@tabacckludge`e}
\DeclareInputText{"0F8}{\o}
\DeclareInputText{"0E9}{\@tabacckludge'e}
\DeclareInputText{"0F9}{\@tabacckludge`u}
\DeclareInputText{"0EA}{\^e}
\DeclareInputText{"0FA}{\@tabacckludge'u}
\DeclareInputText{"0EB}{\"e}
\DeclareInputText{"0FB}{\^u}
\DeclareInputText{"0EC}{\@tabacckludge`\i}
\DeclareInputText{"0FC}{\"u}
\DeclareInputText{"0ED}{\@tabacckludge'\i}
\DeclareInputText{"0FD}{\@tabacckludge'y}
\DeclareInputText{"0EE}{\^\i}
\DeclareInputText{"0FE}{\th}
\DeclareInputText{"0EF}{\"\i}
\DeclareInputText{"0FF}{\"y}
\endinput
% Usage:
% \documentclass{...}
% \usepackage{textcomp} % this package is required!
% \usepackage[latin1jk]{inputenc}
% ...
% \begin{document}
%
% I decided to make \emph{all} characters text, even times and divide, in
% order to make it work in verbatim style environments. A number of control
% sequences refers to the textcomp package of Sebastian Rahtz. The text
% companion fonts are needed to display those characters.
%
% \textcurrency, \textdegree, \texttwosuperior, \textthreesuperior, 
% \textmu, \textonehalf, \textmultiply, and \textdivide are defined in 
% the textcomp package using the text companion font (TS1 coding).
%
% This file is supported by
%
% J"org Knappen
% Professional (La)TeX consultant
% Barbarossaring 43
% D-55118 Mainz
% Allemagne
%
% knappen@vkpmzd.kph.uni-mainz.de
%
%% End of file `latin1jk.def'.
