%%
%% This is file `cpctt.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% cyinpenc.dtx  (with options: `CTT')
%% 
%% IMPORTANT NOTICE:
%% 
%% For the copyright see the source file.
%% 
%% Any modified versions of this file must be renamed
%% with new filenames distinct from cpctt.def.
%% 
%% For distribution of the original source see the terms
%% for copying and modification in the file cyinpenc.dtx.
%% 
%% This generated file may be distributed as long as the
%% original source files, as listed above, are part of the
%% same distribution. (The sources need not necessarily be
%% in the same archive or directory.)
\ProvidesFile{cpctt.def}
  [1998/09/26 v1.0 Input encoding file]
\DeclareInputText{171}{\guillemotleft}
\DeclareInputText{187}{\guillemotright}
\DeclareInputText{192}{\CYRA}
\DeclareInputText{193}{\CYRB}
\DeclareInputText{194}{\CYRV}
\DeclareInputText{195}{\CYRG}
\DeclareInputText{196}{\CYRD}
\DeclareInputText{197}{\CYRE}
\DeclareInputText{168}{\CYRYO}
\DeclareInputText{198}{\CYRZH}
\DeclareInputText{199}{\CYRZ}
\DeclareInputText{200}{\CYRI}
\DeclareInputText{201}{\CYRISHRT}
\DeclareInputText{202}{\CYRK}
\DeclareInputText{203}{\CYRL}
\DeclareInputText{204}{\CYRM}
\DeclareInputText{205}{\CYRN}
\DeclareInputText{206}{\CYRO}
\DeclareInputText{170}{\CYROTLD}
\DeclareInputText{207}{\CYRP}
\DeclareInputText{208}{\CYRR}
\DeclareInputText{209}{\CYRS}
\DeclareInputText{210}{\CYRT}
\DeclareInputText{211}{\CYRU}
\DeclareInputText{175}{\CYRY}
\DeclareInputText{212}{\CYRF}
\DeclareInputText{213}{\CYRH}
\DeclareInputText{214}{\CYRC}
\DeclareInputText{215}{\CYRCH}
\DeclareInputText{216}{\CYRSH}
\DeclareInputText{217}{\CYRSHCH}
\DeclareInputText{218}{\CYRHRDSN}
\DeclareInputText{219}{\CYRERY}
\DeclareInputText{220}{\CYRSFTSN}
\DeclareInputText{221}{\CYREREV}
\DeclareInputText{222}{\CYRYU}
\DeclareInputText{223}{\CYRYA}
\DeclareInputText{224}{\cyra}
\DeclareInputText{225}{\cyrb}
\DeclareInputText{226}{\cyrv}
\DeclareInputText{227}{\cyrg}
\DeclareInputText{228}{\cyrd}
\DeclareInputText{229}{\cyre}
\DeclareInputText{184}{\cyryo}
\DeclareInputText{230}{\cyrzh}
\DeclareInputText{231}{\cyrz}
\DeclareInputText{232}{\cyri}
\DeclareInputText{233}{\cyrishrt}
\DeclareInputText{234}{\cyrk}
\DeclareInputText{235}{\cyrl}
\DeclareInputText{236}{\cyrm}
\DeclareInputText{237}{\cyrn}
\DeclareInputText{238}{\cyro}
\DeclareInputText{186}{\cyrotld}
\DeclareInputText{239}{\cyrp}
\DeclareInputText{240}{\cyrr}
\DeclareInputText{241}{\cyrs}
\DeclareInputText{242}{\cyrt}
\DeclareInputText{243}{\cyru}
\DeclareInputText{191}{\cyry}
\DeclareInputText{244}{\cyrf}
\DeclareInputText{245}{\cyrh}
\DeclareInputText{246}{\cyrc}
\DeclareInputText{247}{\cyrch}
\DeclareInputText{248}{\cyrsh}
\DeclareInputText{249}{\cyrshch}
\DeclareInputText{250}{\cyrhrdsn}
\DeclareInputText{251}{\cyrery}
\DeclareInputText{252}{\cyrsftsn}
\DeclareInputText{253}{\cyrerev}
\DeclareInputText{254}{\cyryu}
\DeclareInputText{255}{\cyrya}
\endinput
%%
%% End of file `cpctt.def'.
