%%
%% This is file `lcyenc.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% cyrillic.fdd  (with options: `LCYenc')
%% 
%% This is a generated file.
%% 
%% Copyright 1995, 1996 CyrTUG and any individual
%% authors listed elsewhere in this file.
%% 
%% 
%% This is a generated file.
%% 
%% Copyright 1996 Johannes L. Braams and any individual authors
%% listed elsewhere in this file.  All rights reserved.
%% 
%% For further copyright information, and conditions for modification
%% and distribution, see any other copyright notices in this file.
%% 
%% This file is part of the Babel system, release 3.6.
%% ---------------------------------------------------
%%   This system is distributed in the hope that it will be useful,
%%   but WITHOUT ANY WARRANTY; without even the implied warranty of
%%   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
%% 
%%   For error reports concerning UNCHANGED versions of this file no
%%   more than one year old, see bugs.txt.
%% 
%%   Please do not request updates from me directly.  Primary
%%   distribution is through the CTAN archives.
%% 
%% 
%% IMPORTANT COPYRIGHT NOTICE:
%% 
%% You are NOT ALLOWED to distribute this file alone.
%% 
%% You are allowed to distribute this file under the condition that it
%% is distributed together with all the files listed in manifest.txt.
%% 
%% If you receive only some of these files from someone, complain!
%% 
%% 
%% Permission is granted to customize the declarations in this file to
%% serve the needs of your installation, provided that you comply with
%% the conditions in the file legal.txt.
%% 
%% However, NO PERMISSION is granted to distribute a modified version
%% of this file under its original name.
%% 
%% 
%% MODIFICATION ADVICE:
%% 
%% If you want to customize this file, it is best to make a copy of
%% the source file(s) from which it was produced.  Use a different
%% name for your copy(ies) and modify the copy(ies); this will ensure
%% that your modifications do not get overwritten when you install a
%% new release of the standard system.
%% 
%% You can then easily distribute your modifications by distributing
%% the modified and renamed copy of the source file, together with a
%% suitable .ins file, taking care to observe the conditions in
%% legal.txt; this will ensure that other users can safely use
%% your modifications.
%% 
%% The names of the source files used are shown above.
%% 
%% 
%% 
\ProvidesFile{lcyenc.def}
        [1998/09/10 v3.0c
         8-bit Cyrillic font encoding]
\@ifl@aded{ltx}{textmath}\relax{\input{textmath.ltx}}
\DeclareFontEncoding{LCY}{}{}
\DeclareFontSubstitution{LCY}{cmr}{m}{n}
\DeclareErrorFont{LCY}{cmr}{m}{n}{10}
\DeclareSymbolFont{LCYletters}{LCY}\rmdefault\mddefault\updefault
\SetSymbolFont{LCYletters}{bold}{LCY}\rmdefault\bfdefault\updefault
\ProvideTextCommand{\copyright}{LCY}
  {\textcircled{\textlatin{c}}}
\ProvideTextCommand{\textregistered}{LCY}
  {\textcircled{\latintext\textsc r}}
\ProvideTextCommand{\textrademark}{LCY}
  {\textsuperscript{\latintext TM}}
\ProvideTextCommand{\SS}{LCY}
  {\textlatin{SS}}
\def\@tmpa#1#2{%
  \DeclareTextMathSymbol#1{LCY}{\mathalpha}{LCYletters}{#2}}
\def\@tmpb#1#2#3#4{%
  \ifx#1\undefined
    \expandafter\def\expandafter\@uclclist\expandafter{\@uclclist#3#1}%
  \fi
  \@tmpa#1{#2}\@tmpa#3{#4}%
  \lccode#2=#4 \lccode#4=#4
  \sfcode#2=999 \sfcode#4=1000 }
\@tmpb{\CYRA}{128}{\cyra}{160}
\@tmpb{\CYRB}{129}{\cyrb}{161}
\@tmpb{\CYRV}{130}{\cyrv}{162}
\@tmpb{\CYRG}{131}{\cyrg}{163}
\@tmpb{\CYRD}{132}{\cyrd}{164}
\@tmpb{\CYRE}{133}{\cyre}{165}
\@tmpb{\CYRZH}{134}{\cyrzh}{166}
\@tmpb{\CYRZ}{135}{\cyrz}{167}
\@tmpb{\CYRI}{136}{\cyri}{168}
\@tmpb{\CYRISHRT}{137}{\cyrishrt}{169}
\@tmpb{\CYRK}{138}{\cyrk}{170}
\@tmpb{\CYRL}{139}{\cyrl}{171}
\@tmpb{\CYRM}{140}{\cyrm}{172}
\@tmpb{\CYRN}{141}{\cyrn}{173}
\@tmpb{\CYRO}{142}{\cyro}{174}
\@tmpb{\CYRP}{143}{\cyrp}{175}
\@tmpb{\CYRR}{144}{\cyrr}{224}
\@tmpb{\CYRS}{145}{\cyrs}{225}
\@tmpb{\CYRT}{146}{\cyrt}{226}
\@tmpb{\CYRU}{147}{\cyru}{227}
\@tmpb{\CYRF}{148}{\cyrf}{228}
\@tmpb{\CYRH}{149}{\cyrh}{229}
\@tmpb{\CYRC}{150}{\cyrc}{230}
\@tmpb{\CYRCH}{151}{\cyrch}{231}
\@tmpb{\CYRSH}{152}{\cyrsh}{232}
\@tmpb{\CYRSHCH}{153}{\cyrshch}{233}
\@tmpb{\CYRHRDSN}{154}{\cyrhrdsn}{234}
\@tmpb{\CYRERY}{155}{\cyrery}{235}
\@tmpb{\CYRSFTSN}{156}{\cyrsftsn}{236}
\@tmpb{\CYREREV}{157}{\cyrerev}{237}
\@tmpb{\CYRYU}{158}{\cyryu}{238}
\@tmpb{\CYRYA}{159}{\cyrya}{239}
\@tmpb{\CYRYO}{240}{\cyryo}{241}
\@tmpb{\CYRGUP}{242}{\cyrgup}{243}
\@tmpb{\CYRIE}{244}{\cyrie}{245}
\@tmpb{\CYRII}{246}{\cyrii}{247}
\@tmpb{\CYRYI}{248}{\cyryi}{249}
\@tmpb{\CYRUSHRT}{250}{\cyrushrt}{251}
\DeclareTextSymbol\textnumero{LCY}{252}
\DeclareMathSymbol\mathnumero{\mathalpha}{LCYletters}{252}
\DeclareRobustCommand\numero{\ifmmode\mathnumero\else\textnumero\fi}
\DeclareTextSymbol\guillemotleft{LCY}{253}
\DeclareTextSymbol\guillemotright{LCY}{254}
\DeclareTextSymbol\cyrdash{LCY}{196}
\DeclareTextSymbol\textcurrency{LCY}{197}
\DeclareTextSymbol\quotedblbase{LCY}{255}
\endinput
%%
%% End of file `lcyenc.def'.
