%%
%% This is file `hdvipson.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% hyperref.dtx  (with options: `dvipsone')
%% 
%% File: hyperref.dtx Copyright (C) 1995, 1996, 1997, 1998 Sebastian Rahtz
\def\@pdfborder{0 0 65781}
\input{pdfmark.def}%
\def\@pdfproducer{dvipsone + Distiller}
\def\PDF@FinishDoc{
 \special{PDF: Keywords \@pdfkeywords}%
 \special{PDF: Title \@pdftitle}%
 \special{PDF: Creator \@pdfcreator}%
 \special{PDF: Author \@pdfauthor}%
 \special{PDF: Producer \@pdfproducer}%
 \special{PDF: Subject \@pdfsubject}%
}
\def\PDF@SetupDoc{
 \pdfmark{pdfmark=/DOCVIEW,
   Page=\@pdfstartpage,
   View=\@pdfstartview,
   URI={<< /Base (\@baseurl) >>},
   PageMode=\@pdfpagemode
   }%
 \ifx\@pdfpagescrop\@empty\else
   \pdfmark{pdfmark=/PAGES,CropBox=\@pdfpagescrop}%
 \fi
 \pdfmark{pdfmark=/PUT,Raw={
  \string{Catalog\string} <<
   /ViewerPreferences <<
  \ifhy@toolbar\else /HideToolbar true \fi
  \ifhy@menubar\else /HideMenubar true \fi
  \ifhy@windowui\else /HideWindowUI true \fi
  \ifhy@fitwindow /FitWindow true \fi
  \ifhy@centerwindow /CenterWindow true \fi
   >>
  \ifx\pdf@pagelayout\@empty\else/PageLayout /\pdf@pagelayout\space\fi
  >>}}%
}
\def\literalps@out#1{\special{ps:#1}}%
\def\pdf@setheight{\literalps@out{%
  \strip@pt@and@otherjunk\baselineskip
  \space 2 sub
  PDFToDvips /HyperBase exch def
  }%
}
\providecommand\@pdfview{XYZ}
\providecommand\@pdfviewparams{ gsave revscl currentpoint grestore 72 add
   exch pop null exch null}
\def\PSHyperAnchorStart{\literalps@out{HyperStart }}
\def\PSHyperAnchorEnd{%
  \pdf@setheight
  \literalps@out{HyperAutoEnd HyperAutoVoff }%
}
\def\PSHyperLinkStart{\literalps@out{HyperStart }}
\def\PSHyperLinkEnd{%
  \pdf@setheight
  \literalps@out{HyperAutoEnd}%
}
\def\PSHyperRectStart{\literalps@out{HyperStart }}
\def\PSHyperRectEnd{\literalps@out{HyperEnd HyperVoff }}
\special{headertext=
/DvipsToPDF { 65781 div  } def
/PDFToDvips { 65781 mul } def
/HyperBorder  { 1 PDFToDvips } def
/HyperVoff {
   currentpoint exch pop DvipsToPDF /pdf@voff exch def
 } def
/HyperAutoVoff {
   currentpoint exch pop
    HyperBase sub % baseline skip
    DvipsToPDF /pdf@voff exch def
 } def
/HyperStart {
   currentpoint
    HyperBorder add /pdf@lly exch def
    dup   DvipsToPDF /pdf@hoff exch def
    HyperBorder sub /pdf@llx exch def
} def
/HyperAutoEnd  {
   currentpoint
    HyperBase sub /pdf@ury exch def
    /pdf@urx exch def
} def
/HyperEnd  {
   currentpoint
    HyperBorder sub /pdf@ury exch def
    HyperBorder add /pdf@urx exch def
 } def
 systemdict
 /pdfmark known not
 {userdict /pdfmark systemdict /cleartomark get put} if
}
\AtBeginDocument{%
  \ifhy@colorlinks
   \def\@pdfborder{0 0 0}%
  \fi
}
\endinput
%%
%% End of file `hdvipson.def'.
