%%
%% This is file `hvtexhtm.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% hyperref.dtx  (with options: `hvtexhtml')
%% 
%% File: hyperref.dtx Copyright (C) 1995, 1996, 1997, 1998 Sebastian Rahtz
\RequirePackage{vtexhtml}
\newif\if@Localurl
\def\PDF@FinishDoc{}
\def\PDF@SetupDoc{%
 \ifx\@baseurl\@empty\else
  \special{!direct <base href="\@baseurl">}%
 \fi
}
\def\@urltype{url}
\def\hyper@link#1#2#3{%
 \leavevmode\special{!direct <a
    href=\hyper@quote\hyper@hash#2\hyper@quote>}#3\special{!direct </a>}%
}
\def\hyper@linkurl#1#2{%
  {\hyper@chars
   \leavevmode\MathBSuppress=1\relax
   \special{!direct <a href=\hyper@quote#2\hyper@quote>}%
   #1\MathBSuppress=0\relax\special{!direct </a>}}%
}
\def\hyper@linkfile#1#2#3{%
 \hyper@linkurl{#1}{file:#2\ifx\\#3\\\else\##3\fi}%
}
\def\hyper@linkstart#1#2{%
  \def\@tempa{#1}\ifx\@tempa\@urltype
    \@Localurltrue
    \special{!direct <A href=\hyper@quote#2\hyper@quote>}%
  \else
    \@Localurlfalse
    {\hyper@chars\special{!aref #2}}%
  \fi
}
\def\hyper@linkend{
 \if@Localurl
   \special{!endaref}%
 \else
   \special{!direct </a>}%
 \fi
}
\def\hyper@anchorstart#1{%
 {\hyper@chars\special{!aname #1}%
  \special{!direct <a name=\hyper@quote#1\hyper@quote>}}%
  \hy@activeanchortrue
}
\def\hyper@anchorend{\special{!direct </a>}\hy@activeanchorfalse}
\def\hyper@anchor#1{%
   {\let\protect=\string
   \leavevmode\special{!aname #1}%
   \special{!direct <a name=\hyper@quote #1\hyper@quote>}}%
   \hy@activeanchortrue
   \bgroup\anchor@spot\egroup
   \special{!direct </a>}%
   \hy@activeanchorfalse
}
\def\@Form[#1]{\typeout{Sorry, TeXpider does not yet support FORMs}}
\def\@endForm{}
\def\@Gauge[#1]#2#3#4{% parameters, label, minimum, maximum
  \typeout{Sorry, TeXpider does not yet support FORM gauges}%
}
\def\@TextField[#1]#2{% parameters, label
  \typeout{Sorry, TeXpider does not yet support FORM text fields}%
  }
\def\@CheckBox[#1]#2{% parameters, label
  \typeout{Sorry, TeXpider does not yet support FORM checkboxes}%
  }
\def\@ChoiceMenu[#1]#2#3{% parameters, label, choices
  \typeout{Sorry, TeXpider does not yet support FORM choice menus}%
}
\def\@PushButton[#1]#2{% parameters, label
  \typeout{Sorry, TeXpider does not yet support FORM pushbuttons}%
}
\def\@Reset[#1]#2{\typeout{Sorry, TeXpider does not yet support FORMs}}
\def\@Submit[#1]#2{\typeout{Sorry, TeXpider does not yet support FORMs}}
\endinput
%%
%% End of file `hvtexhtm.def'.
